.materialize-red {
  background-color: #e51c23 !important; }

.materialize-red-text {
  color: #e51c23 !important; }

.materialize-red.lighten-5 {
  background-color: #fdeaeb !important; }

.materialize-red-text.text-lighten-5 {
  color: #fdeaeb !important; }

.materialize-red.lighten-4 {
  background-color: #f8c1c3 !important; }

.materialize-red-text.text-lighten-4 {
  color: #f8c1c3 !important; }

.materialize-red.lighten-3 {
  background-color: #f3989b !important; }

.materialize-red-text.text-lighten-3 {
  color: #f3989b !important; }

.materialize-red.lighten-2 {
  background-color: #ee6e73 !important; }

.materialize-red-text.text-lighten-2 {
  color: #ee6e73 !important; }

.materialize-red.lighten-1 {
  background-color: #ea454b !important; }

.materialize-red-text.text-lighten-1 {
  color: #ea454b !important; }

.materialize-red.darken-1 {
  background-color: #d0181e !important; }

.materialize-red-text.text-darken-1 {
  color: #d0181e !important; }

.materialize-red.darken-2, .materialize-red.btn-delete {
  background-color: #b9151b !important; }

.materialize-red-text.text-darken-2 {
  color: #b9151b !important; }

.materialize-red.darken-3 {
  background-color: #a21318 !important; }

.materialize-red-text.text-darken-3 {
  color: #a21318 !important; }

.materialize-red.darken-4 {
  background-color: #8b1014 !important; }

.materialize-red-text.text-darken-4 {
  color: #8b1014 !important; }

.red, .btn-delete {
  background-color: #F44336 !important; }

.red-text {
  color: #F44336 !important; }

.red.lighten-5, .lighten-5.btn-delete {
  background-color: #FFEBEE !important; }

.red-text.text-lighten-5 {
  color: #FFEBEE !important; }

.red.lighten-4, .lighten-4.btn-delete {
  background-color: #FFCDD2 !important; }

.red-text.text-lighten-4 {
  color: #FFCDD2 !important; }

.red.lighten-3, .lighten-3.btn-delete {
  background-color: #EF9A9A !important; }

.red-text.text-lighten-3 {
  color: #EF9A9A !important; }

.red.lighten-2, .lighten-2.btn-delete {
  background-color: #E57373 !important; }

.red-text.text-lighten-2 {
  color: #E57373 !important; }

.red.lighten-1, .lighten-1.btn-delete {
  background-color: #EF5350 !important; }

.red-text.text-lighten-1 {
  color: #EF5350 !important; }

.red.darken-1, .darken-1.btn-delete {
  background-color: #E53935 !important; }

.red-text.text-darken-1 {
  color: #E53935 !important; }

.red.darken-2, .btn-delete {
  background-color: #D32F2F !important; }

.red-text.text-darken-2 {
  color: #D32F2F !important; }

.red.darken-3, .darken-3.btn-delete {
  background-color: #C62828 !important; }

.red-text.text-darken-3 {
  color: #C62828 !important; }

.red.darken-4, .darken-4.btn-delete {
  background-color: #B71C1C !important; }

.red-text.text-darken-4 {
  color: #B71C1C !important; }

.red.accent-1, .accent-1.btn-delete {
  background-color: #FF8A80 !important; }

.red-text.text-accent-1 {
  color: #FF8A80 !important; }

.red.accent-2, .accent-2.btn-delete {
  background-color: #FF5252 !important; }

.red-text.text-accent-2 {
  color: #FF5252 !important; }

.red.accent-3, .accent-3.btn-delete {
  background-color: #FF1744 !important; }

.red-text.text-accent-3 {
  color: #FF1744 !important; }

.red.accent-4, .accent-4.btn-delete {
  background-color: #D50000 !important; }

.red-text.text-accent-4 {
  color: #D50000 !important; }

.pink {
  background-color: #e91e63 !important; }

.pink-text {
  color: #e91e63 !important; }

.pink.lighten-5 {
  background-color: #fce4ec !important; }

.pink-text.text-lighten-5 {
  color: #fce4ec !important; }

.pink.lighten-4 {
  background-color: #f8bbd0 !important; }

.pink-text.text-lighten-4 {
  color: #f8bbd0 !important; }

.pink.lighten-3 {
  background-color: #f48fb1 !important; }

.pink-text.text-lighten-3 {
  color: #f48fb1 !important; }

.pink.lighten-2 {
  background-color: #f06292 !important; }

.pink-text.text-lighten-2 {
  color: #f06292 !important; }

.pink.lighten-1 {
  background-color: #ec407a !important; }

.pink-text.text-lighten-1 {
  color: #ec407a !important; }

.pink.darken-1 {
  background-color: #d81b60 !important; }

.pink-text.text-darken-1 {
  color: #d81b60 !important; }

.pink.darken-2, .pink.btn-delete {
  background-color: #c2185b !important; }

.pink-text.text-darken-2 {
  color: #c2185b !important; }

.pink.darken-3 {
  background-color: #ad1457 !important; }

.pink-text.text-darken-3 {
  color: #ad1457 !important; }

.pink.darken-4 {
  background-color: #880e4f !important; }

.pink-text.text-darken-4 {
  color: #880e4f !important; }

.pink.accent-1 {
  background-color: #ff80ab !important; }

.pink-text.text-accent-1 {
  color: #ff80ab !important; }

.pink.accent-2 {
  background-color: #ff4081 !important; }

.pink-text.text-accent-2 {
  color: #ff4081 !important; }

.pink.accent-3 {
  background-color: #f50057 !important; }

.pink-text.text-accent-3 {
  color: #f50057 !important; }

.pink.accent-4 {
  background-color: #c51162 !important; }

.pink-text.text-accent-4 {
  color: #c51162 !important; }

.purple {
  background-color: #9c27b0 !important; }

.purple-text {
  color: #9c27b0 !important; }

.purple.lighten-5 {
  background-color: #f3e5f5 !important; }

.purple-text.text-lighten-5 {
  color: #f3e5f5 !important; }

.purple.lighten-4 {
  background-color: #e1bee7 !important; }

.purple-text.text-lighten-4 {
  color: #e1bee7 !important; }

.purple.lighten-3 {
  background-color: #ce93d8 !important; }

.purple-text.text-lighten-3 {
  color: #ce93d8 !important; }

.purple.lighten-2 {
  background-color: #ba68c8 !important; }

.purple-text.text-lighten-2 {
  color: #ba68c8 !important; }

.purple.lighten-1 {
  background-color: #ab47bc !important; }

.purple-text.text-lighten-1 {
  color: #ab47bc !important; }

.purple.darken-1 {
  background-color: #8e24aa !important; }

.purple-text.text-darken-1 {
  color: #8e24aa !important; }

.purple.darken-2, .purple.btn-delete {
  background-color: #7b1fa2 !important; }

.purple-text.text-darken-2 {
  color: #7b1fa2 !important; }

.purple.darken-3 {
  background-color: #6a1b9a !important; }

.purple-text.text-darken-3 {
  color: #6a1b9a !important; }

.purple.darken-4 {
  background-color: #4a148c !important; }

.purple-text.text-darken-4 {
  color: #4a148c !important; }

.purple.accent-1 {
  background-color: #ea80fc !important; }

.purple-text.text-accent-1 {
  color: #ea80fc !important; }

.purple.accent-2 {
  background-color: #e040fb !important; }

.purple-text.text-accent-2 {
  color: #e040fb !important; }

.purple.accent-3 {
  background-color: #d500f9 !important; }

.purple-text.text-accent-3 {
  color: #d500f9 !important; }

.purple.accent-4 {
  background-color: #aa00ff !important; }

.purple-text.text-accent-4 {
  color: #aa00ff !important; }

.deep-purple {
  background-color: #673ab7 !important; }

.deep-purple-text {
  color: #673ab7 !important; }

.deep-purple.lighten-5 {
  background-color: #ede7f6 !important; }

.deep-purple-text.text-lighten-5 {
  color: #ede7f6 !important; }

.deep-purple.lighten-4 {
  background-color: #d1c4e9 !important; }

.deep-purple-text.text-lighten-4 {
  color: #d1c4e9 !important; }

.deep-purple.lighten-3 {
  background-color: #b39ddb !important; }

.deep-purple-text.text-lighten-3 {
  color: #b39ddb !important; }

.deep-purple.lighten-2 {
  background-color: #9575cd !important; }

.deep-purple-text.text-lighten-2 {
  color: #9575cd !important; }

.deep-purple.lighten-1 {
  background-color: #7e57c2 !important; }

.deep-purple-text.text-lighten-1 {
  color: #7e57c2 !important; }

.deep-purple.darken-1 {
  background-color: #5e35b1 !important; }

.deep-purple-text.text-darken-1 {
  color: #5e35b1 !important; }

.deep-purple.darken-2, .deep-purple.btn-delete {
  background-color: #512da8 !important; }

.deep-purple-text.text-darken-2 {
  color: #512da8 !important; }

.deep-purple.darken-3 {
  background-color: #4527a0 !important; }

.deep-purple-text.text-darken-3 {
  color: #4527a0 !important; }

.deep-purple.darken-4 {
  background-color: #311b92 !important; }

.deep-purple-text.text-darken-4 {
  color: #311b92 !important; }

.deep-purple.accent-1 {
  background-color: #b388ff !important; }

.deep-purple-text.text-accent-1 {
  color: #b388ff !important; }

.deep-purple.accent-2 {
  background-color: #7c4dff !important; }

.deep-purple-text.text-accent-2 {
  color: #7c4dff !important; }

.deep-purple.accent-3 {
  background-color: #651fff !important; }

.deep-purple-text.text-accent-3 {
  color: #651fff !important; }

.deep-purple.accent-4 {
  background-color: #6200ea !important; }

.deep-purple-text.text-accent-4 {
  color: #6200ea !important; }

.indigo {
  background-color: #3f51b5 !important; }

.indigo-text {
  color: #3f51b5 !important; }

.indigo.lighten-5 {
  background-color: #e8eaf6 !important; }

.indigo-text.text-lighten-5 {
  color: #e8eaf6 !important; }

.indigo.lighten-4 {
  background-color: #c5cae9 !important; }

.indigo-text.text-lighten-4 {
  color: #c5cae9 !important; }

.indigo.lighten-3 {
  background-color: #9fa8da !important; }

.indigo-text.text-lighten-3 {
  color: #9fa8da !important; }

.indigo.lighten-2 {
  background-color: #7986cb !important; }

.indigo-text.text-lighten-2 {
  color: #7986cb !important; }

.indigo.lighten-1 {
  background-color: #5c6bc0 !important; }

.indigo-text.text-lighten-1 {
  color: #5c6bc0 !important; }

.indigo.darken-1 {
  background-color: #3949ab !important; }

.indigo-text.text-darken-1 {
  color: #3949ab !important; }

.indigo.darken-2, .indigo.btn-delete {
  background-color: #303f9f !important; }

.indigo-text.text-darken-2 {
  color: #303f9f !important; }

.indigo.darken-3 {
  background-color: #283593 !important; }

.indigo-text.text-darken-3 {
  color: #283593 !important; }

.indigo.darken-4 {
  background-color: #1a237e !important; }

.indigo-text.text-darken-4 {
  color: #1a237e !important; }

.indigo.accent-1 {
  background-color: #8c9eff !important; }

.indigo-text.text-accent-1 {
  color: #8c9eff !important; }

.indigo.accent-2 {
  background-color: #536dfe !important; }

.indigo-text.text-accent-2 {
  color: #536dfe !important; }

.indigo.accent-3 {
  background-color: #3d5afe !important; }

.indigo-text.text-accent-3 {
  color: #3d5afe !important; }

.indigo.accent-4 {
  background-color: #304ffe !important; }

.indigo-text.text-accent-4 {
  color: #304ffe !important; }

.blue {
  background-color: #2196F3 !important; }

.blue-text {
  color: #2196F3 !important; }

.blue.lighten-5 {
  background-color: #E3F2FD !important; }

.blue-text.text-lighten-5 {
  color: #E3F2FD !important; }

.blue.lighten-4 {
  background-color: #BBDEFB !important; }

.blue-text.text-lighten-4 {
  color: #BBDEFB !important; }

.blue.lighten-3 {
  background-color: #90CAF9 !important; }

.blue-text.text-lighten-3 {
  color: #90CAF9 !important; }

.blue.lighten-2 {
  background-color: #64B5F6 !important; }

.blue-text.text-lighten-2 {
  color: #64B5F6 !important; }

.blue.lighten-1 {
  background-color: #42A5F5 !important; }

.blue-text.text-lighten-1 {
  color: #42A5F5 !important; }

.blue.darken-1 {
  background-color: #1E88E5 !important; }

.blue-text.text-darken-1 {
  color: #1E88E5 !important; }

.blue.darken-2, .blue.btn-delete {
  background-color: #1976D2 !important; }

.blue-text.text-darken-2 {
  color: #1976D2 !important; }

.blue.darken-3 {
  background-color: #1565C0 !important; }

.blue-text.text-darken-3 {
  color: #1565C0 !important; }

.blue.darken-4 {
  background-color: #0D47A1 !important; }

.blue-text.text-darken-4 {
  color: #0D47A1 !important; }

.blue.accent-1 {
  background-color: #82B1FF !important; }

.blue-text.text-accent-1 {
  color: #82B1FF !important; }

.blue.accent-2 {
  background-color: #448AFF !important; }

.blue-text.text-accent-2 {
  color: #448AFF !important; }

.blue.accent-3 {
  background-color: #2979FF !important; }

.blue-text.text-accent-3 {
  color: #2979FF !important; }

.blue.accent-4 {
  background-color: #2962FF !important; }

.blue-text.text-accent-4 {
  color: #2962FF !important; }

.light-blue {
  background-color: #03a9f4 !important; }

.light-blue-text {
  color: #03a9f4 !important; }

.light-blue.lighten-5 {
  background-color: #e1f5fe !important; }

.light-blue-text.text-lighten-5 {
  color: #e1f5fe !important; }

.light-blue.lighten-4 {
  background-color: #b3e5fc !important; }

.light-blue-text.text-lighten-4 {
  color: #b3e5fc !important; }

.light-blue.lighten-3 {
  background-color: #81d4fa !important; }

.light-blue-text.text-lighten-3 {
  color: #81d4fa !important; }

.light-blue.lighten-2 {
  background-color: #4fc3f7 !important; }

.light-blue-text.text-lighten-2 {
  color: #4fc3f7 !important; }

.light-blue.lighten-1 {
  background-color: #29b6f6 !important; }

.light-blue-text.text-lighten-1 {
  color: #29b6f6 !important; }

.light-blue.darken-1 {
  background-color: #039be5 !important; }

.light-blue-text.text-darken-1 {
  color: #039be5 !important; }

.light-blue.darken-2, .light-blue.btn-delete {
  background-color: #0288d1 !important; }

.light-blue-text.text-darken-2 {
  color: #0288d1 !important; }

.light-blue.darken-3 {
  background-color: #0277bd !important; }

.light-blue-text.text-darken-3 {
  color: #0277bd !important; }

.light-blue.darken-4 {
  background-color: #01579b !important; }

.light-blue-text.text-darken-4 {
  color: #01579b !important; }

.light-blue.accent-1 {
  background-color: #80d8ff !important; }

.light-blue-text.text-accent-1 {
  color: #80d8ff !important; }

.light-blue.accent-2 {
  background-color: #40c4ff !important; }

.light-blue-text.text-accent-2 {
  color: #40c4ff !important; }

.light-blue.accent-3 {
  background-color: #00b0ff !important; }

.light-blue-text.text-accent-3 {
  color: #00b0ff !important; }

.light-blue.accent-4 {
  background-color: #0091ea !important; }

.light-blue-text.text-accent-4 {
  color: #0091ea !important; }

.cyan {
  background-color: #00bcd4 !important; }

.cyan-text {
  color: #00bcd4 !important; }

.cyan.lighten-5 {
  background-color: #e0f7fa !important; }

.cyan-text.text-lighten-5 {
  color: #e0f7fa !important; }

.cyan.lighten-4 {
  background-color: #b2ebf2 !important; }

.cyan-text.text-lighten-4 {
  color: #b2ebf2 !important; }

.cyan.lighten-3 {
  background-color: #80deea !important; }

.cyan-text.text-lighten-3 {
  color: #80deea !important; }

.cyan.lighten-2 {
  background-color: #4dd0e1 !important; }

.cyan-text.text-lighten-2 {
  color: #4dd0e1 !important; }

.cyan.lighten-1 {
  background-color: #26c6da !important; }

.cyan-text.text-lighten-1 {
  color: #26c6da !important; }

.cyan.darken-1 {
  background-color: #00acc1 !important; }

.cyan-text.text-darken-1 {
  color: #00acc1 !important; }

.cyan.darken-2, .cyan.btn-delete {
  background-color: #0097a7 !important; }

.cyan-text.text-darken-2 {
  color: #0097a7 !important; }

.cyan.darken-3 {
  background-color: #00838f !important; }

.cyan-text.text-darken-3 {
  color: #00838f !important; }

.cyan.darken-4 {
  background-color: #006064 !important; }

.cyan-text.text-darken-4 {
  color: #006064 !important; }

.cyan.accent-1 {
  background-color: #84ffff !important; }

.cyan-text.text-accent-1 {
  color: #84ffff !important; }

.cyan.accent-2 {
  background-color: #18ffff !important; }

.cyan-text.text-accent-2 {
  color: #18ffff !important; }

.cyan.accent-3 {
  background-color: #00e5ff !important; }

.cyan-text.text-accent-3 {
  color: #00e5ff !important; }

.cyan.accent-4 {
  background-color: #00b8d4 !important; }

.cyan-text.text-accent-4 {
  color: #00b8d4 !important; }

.teal {
  background-color: #009688 !important; }

.teal-text {
  color: #009688 !important; }

.teal.lighten-5 {
  background-color: #e0f2f1 !important; }

.teal-text.text-lighten-5 {
  color: #e0f2f1 !important; }

.teal.lighten-4 {
  background-color: #b2dfdb !important; }

.teal-text.text-lighten-4 {
  color: #b2dfdb !important; }

.teal.lighten-3 {
  background-color: #80cbc4 !important; }

.teal-text.text-lighten-3 {
  color: #80cbc4 !important; }

.teal.lighten-2 {
  background-color: #4db6ac !important; }

.teal-text.text-lighten-2 {
  color: #4db6ac !important; }

.teal.lighten-1 {
  background-color: #26a69a !important; }

.teal-text.text-lighten-1 {
  color: #26a69a !important; }

.teal.darken-1 {
  background-color: #00897b !important; }

.teal-text.text-darken-1 {
  color: #00897b !important; }

.teal.darken-2, .teal.btn-delete {
  background-color: #00796b !important; }

.teal-text.text-darken-2 {
  color: #00796b !important; }

.teal.darken-3 {
  background-color: #00695c !important; }

.teal-text.text-darken-3 {
  color: #00695c !important; }

.teal.darken-4 {
  background-color: #004d40 !important; }

.teal-text.text-darken-4 {
  color: #004d40 !important; }

.teal.accent-1 {
  background-color: #a7ffeb !important; }

.teal-text.text-accent-1 {
  color: #a7ffeb !important; }

.teal.accent-2 {
  background-color: #64ffda !important; }

.teal-text.text-accent-2 {
  color: #64ffda !important; }

.teal.accent-3 {
  background-color: #1de9b6 !important; }

.teal-text.text-accent-3 {
  color: #1de9b6 !important; }

.teal.accent-4 {
  background-color: #00bfa5 !important; }

.teal-text.text-accent-4 {
  color: #00bfa5 !important; }

.green {
  background-color: #4CAF50 !important; }

.green-text {
  color: #4CAF50 !important; }

.green.lighten-5 {
  background-color: #E8F5E9 !important; }

.green-text.text-lighten-5 {
  color: #E8F5E9 !important; }

.green.lighten-4 {
  background-color: #C8E6C9 !important; }

.green-text.text-lighten-4 {
  color: #C8E6C9 !important; }

.green.lighten-3 {
  background-color: #A5D6A7 !important; }

.green-text.text-lighten-3 {
  color: #A5D6A7 !important; }

.green.lighten-2 {
  background-color: #81C784 !important; }

.green-text.text-lighten-2 {
  color: #81C784 !important; }

.green.lighten-1 {
  background-color: #66BB6A !important; }

.green-text.text-lighten-1 {
  color: #66BB6A !important; }

.green.darken-1 {
  background-color: #43A047 !important; }

.green-text.text-darken-1 {
  color: #43A047 !important; }

.green.darken-2, .green.btn-delete {
  background-color: #388E3C !important; }

.green-text.text-darken-2 {
  color: #388E3C !important; }

.green.darken-3 {
  background-color: #2E7D32 !important; }

.green-text.text-darken-3 {
  color: #2E7D32 !important; }

.green.darken-4 {
  background-color: #1B5E20 !important; }

.green-text.text-darken-4 {
  color: #1B5E20 !important; }

.green.accent-1 {
  background-color: #B9F6CA !important; }

.green-text.text-accent-1 {
  color: #B9F6CA !important; }

.green.accent-2 {
  background-color: #69F0AE !important; }

.green-text.text-accent-2 {
  color: #69F0AE !important; }

.green.accent-3 {
  background-color: #00E676 !important; }

.green-text.text-accent-3 {
  color: #00E676 !important; }

.green.accent-4 {
  background-color: #00C853 !important; }

.green-text.text-accent-4 {
  color: #00C853 !important; }

.light-green {
  background-color: #8bc34a !important; }

.light-green-text {
  color: #8bc34a !important; }

.light-green.lighten-5 {
  background-color: #f1f8e9 !important; }

.light-green-text.text-lighten-5 {
  color: #f1f8e9 !important; }

.light-green.lighten-4 {
  background-color: #dcedc8 !important; }

.light-green-text.text-lighten-4 {
  color: #dcedc8 !important; }

.light-green.lighten-3 {
  background-color: #c5e1a5 !important; }

.light-green-text.text-lighten-3 {
  color: #c5e1a5 !important; }

.light-green.lighten-2 {
  background-color: #aed581 !important; }

.light-green-text.text-lighten-2 {
  color: #aed581 !important; }

.light-green.lighten-1 {
  background-color: #9ccc65 !important; }

.light-green-text.text-lighten-1 {
  color: #9ccc65 !important; }

.light-green.darken-1 {
  background-color: #7cb342 !important; }

.light-green-text.text-darken-1 {
  color: #7cb342 !important; }

.light-green.darken-2, .light-green.btn-delete {
  background-color: #689f38 !important; }

.light-green-text.text-darken-2 {
  color: #689f38 !important; }

.light-green.darken-3 {
  background-color: #558b2f !important; }

.light-green-text.text-darken-3 {
  color: #558b2f !important; }

.light-green.darken-4 {
  background-color: #33691e !important; }

.light-green-text.text-darken-4 {
  color: #33691e !important; }

.light-green.accent-1 {
  background-color: #ccff90 !important; }

.light-green-text.text-accent-1 {
  color: #ccff90 !important; }

.light-green.accent-2 {
  background-color: #b2ff59 !important; }

.light-green-text.text-accent-2 {
  color: #b2ff59 !important; }

.light-green.accent-3 {
  background-color: #76ff03 !important; }

.light-green-text.text-accent-3 {
  color: #76ff03 !important; }

.light-green.accent-4 {
  background-color: #64dd17 !important; }

.light-green-text.text-accent-4 {
  color: #64dd17 !important; }

.lime {
  background-color: #cddc39 !important; }

.lime-text {
  color: #cddc39 !important; }

.lime.lighten-5 {
  background-color: #f9fbe7 !important; }

.lime-text.text-lighten-5 {
  color: #f9fbe7 !important; }

.lime.lighten-4 {
  background-color: #f0f4c3 !important; }

.lime-text.text-lighten-4 {
  color: #f0f4c3 !important; }

.lime.lighten-3 {
  background-color: #e6ee9c !important; }

.lime-text.text-lighten-3 {
  color: #e6ee9c !important; }

.lime.lighten-2 {
  background-color: #dce775 !important; }

.lime-text.text-lighten-2 {
  color: #dce775 !important; }

.lime.lighten-1 {
  background-color: #d4e157 !important; }

.lime-text.text-lighten-1 {
  color: #d4e157 !important; }

.lime.darken-1 {
  background-color: #c0ca33 !important; }

.lime-text.text-darken-1 {
  color: #c0ca33 !important; }

.lime.darken-2, .lime.btn-delete {
  background-color: #afb42b !important; }

.lime-text.text-darken-2 {
  color: #afb42b !important; }

.lime.darken-3 {
  background-color: #9e9d24 !important; }

.lime-text.text-darken-3 {
  color: #9e9d24 !important; }

.lime.darken-4 {
  background-color: #827717 !important; }

.lime-text.text-darken-4 {
  color: #827717 !important; }

.lime.accent-1 {
  background-color: #f4ff81 !important; }

.lime-text.text-accent-1 {
  color: #f4ff81 !important; }

.lime.accent-2 {
  background-color: #eeff41 !important; }

.lime-text.text-accent-2 {
  color: #eeff41 !important; }

.lime.accent-3 {
  background-color: #c6ff00 !important; }

.lime-text.text-accent-3 {
  color: #c6ff00 !important; }

.lime.accent-4 {
  background-color: #aeea00 !important; }

.lime-text.text-accent-4 {
  color: #aeea00 !important; }

.yellow {
  background-color: #ffeb3b !important; }

.yellow-text {
  color: #ffeb3b !important; }

.yellow.lighten-5 {
  background-color: #fffde7 !important; }

.yellow-text.text-lighten-5 {
  color: #fffde7 !important; }

.yellow.lighten-4 {
  background-color: #fff9c4 !important; }

.yellow-text.text-lighten-4 {
  color: #fff9c4 !important; }

.yellow.lighten-3 {
  background-color: #fff59d !important; }

.yellow-text.text-lighten-3 {
  color: #fff59d !important; }

.yellow.lighten-2 {
  background-color: #fff176 !important; }

.yellow-text.text-lighten-2 {
  color: #fff176 !important; }

.yellow.lighten-1 {
  background-color: #ffee58 !important; }

.yellow-text.text-lighten-1 {
  color: #ffee58 !important; }

.yellow.darken-1 {
  background-color: #fdd835 !important; }

.yellow-text.text-darken-1 {
  color: #fdd835 !important; }

.yellow.darken-2, .yellow.btn-delete {
  background-color: #fbc02d !important; }

.yellow-text.text-darken-2 {
  color: #fbc02d !important; }

.yellow.darken-3 {
  background-color: #f9a825 !important; }

.yellow-text.text-darken-3 {
  color: #f9a825 !important; }

.yellow.darken-4 {
  background-color: #f57f17 !important; }

.yellow-text.text-darken-4 {
  color: #f57f17 !important; }

.yellow.accent-1 {
  background-color: #ffff8d !important; }

.yellow-text.text-accent-1 {
  color: #ffff8d !important; }

.yellow.accent-2 {
  background-color: #ffff00 !important; }

.yellow-text.text-accent-2 {
  color: #ffff00 !important; }

.yellow.accent-3 {
  background-color: #ffea00 !important; }

.yellow-text.text-accent-3 {
  color: #ffea00 !important; }

.yellow.accent-4 {
  background-color: #ffd600 !important; }

.yellow-text.text-accent-4 {
  color: #ffd600 !important; }

.amber {
  background-color: #ffc107 !important; }

.amber-text {
  color: #ffc107 !important; }

.amber.lighten-5 {
  background-color: #fff8e1 !important; }

.amber-text.text-lighten-5 {
  color: #fff8e1 !important; }

.amber.lighten-4 {
  background-color: #ffecb3 !important; }

.amber-text.text-lighten-4 {
  color: #ffecb3 !important; }

.amber.lighten-3 {
  background-color: #ffe082 !important; }

.amber-text.text-lighten-3 {
  color: #ffe082 !important; }

.amber.lighten-2 {
  background-color: #ffd54f !important; }

.amber-text.text-lighten-2 {
  color: #ffd54f !important; }

.amber.lighten-1 {
  background-color: #ffca28 !important; }

.amber-text.text-lighten-1 {
  color: #ffca28 !important; }

.amber.darken-1 {
  background-color: #ffb300 !important; }

.amber-text.text-darken-1 {
  color: #ffb300 !important; }

.amber.darken-2, .amber.btn-delete {
  background-color: #ffa000 !important; }

.amber-text.text-darken-2 {
  color: #ffa000 !important; }

.amber.darken-3 {
  background-color: #ff8f00 !important; }

.amber-text.text-darken-3 {
  color: #ff8f00 !important; }

.amber.darken-4 {
  background-color: #ff6f00 !important; }

.amber-text.text-darken-4 {
  color: #ff6f00 !important; }

.amber.accent-1 {
  background-color: #ffe57f !important; }

.amber-text.text-accent-1 {
  color: #ffe57f !important; }

.amber.accent-2 {
  background-color: #ffd740 !important; }

.amber-text.text-accent-2 {
  color: #ffd740 !important; }

.amber.accent-3 {
  background-color: #ffc400 !important; }

.amber-text.text-accent-3 {
  color: #ffc400 !important; }

.amber.accent-4 {
  background-color: #ffab00 !important; }

.amber-text.text-accent-4 {
  color: #ffab00 !important; }

.orange {
  background-color: #ff9800 !important; }

.orange-text {
  color: #ff9800 !important; }

.orange.lighten-5 {
  background-color: #fff3e0 !important; }

.orange-text.text-lighten-5 {
  color: #fff3e0 !important; }

.orange.lighten-4 {
  background-color: #ffe0b2 !important; }

.orange-text.text-lighten-4 {
  color: #ffe0b2 !important; }

.orange.lighten-3 {
  background-color: #ffcc80 !important; }

.orange-text.text-lighten-3 {
  color: #ffcc80 !important; }

.orange.lighten-2 {
  background-color: #ffb74d !important; }

.orange-text.text-lighten-2 {
  color: #ffb74d !important; }

.orange.lighten-1 {
  background-color: #ffa726 !important; }

.orange-text.text-lighten-1 {
  color: #ffa726 !important; }

.orange.darken-1 {
  background-color: #fb8c00 !important; }

.orange-text.text-darken-1 {
  color: #fb8c00 !important; }

.orange.darken-2, .orange.btn-delete {
  background-color: #f57c00 !important; }

.orange-text.text-darken-2 {
  color: #f57c00 !important; }

.orange.darken-3 {
  background-color: #ef6c00 !important; }

.orange-text.text-darken-3 {
  color: #ef6c00 !important; }

.orange.darken-4 {
  background-color: #e65100 !important; }

.orange-text.text-darken-4 {
  color: #e65100 !important; }

.orange.accent-1 {
  background-color: #ffd180 !important; }

.orange-text.text-accent-1 {
  color: #ffd180 !important; }

.orange.accent-2 {
  background-color: #ffab40 !important; }

.orange-text.text-accent-2 {
  color: #ffab40 !important; }

.orange.accent-3 {
  background-color: #ff9100 !important; }

.orange-text.text-accent-3 {
  color: #ff9100 !important; }

.orange.accent-4 {
  background-color: #ff6d00 !important; }

.orange-text.text-accent-4 {
  color: #ff6d00 !important; }

.deep-orange {
  background-color: #ff5722 !important; }

.deep-orange-text {
  color: #ff5722 !important; }

.deep-orange.lighten-5 {
  background-color: #fbe9e7 !important; }

.deep-orange-text.text-lighten-5 {
  color: #fbe9e7 !important; }

.deep-orange.lighten-4 {
  background-color: #ffccbc !important; }

.deep-orange-text.text-lighten-4 {
  color: #ffccbc !important; }

.deep-orange.lighten-3 {
  background-color: #ffab91 !important; }

.deep-orange-text.text-lighten-3 {
  color: #ffab91 !important; }

.deep-orange.lighten-2 {
  background-color: #ff8a65 !important; }

.deep-orange-text.text-lighten-2 {
  color: #ff8a65 !important; }

.deep-orange.lighten-1 {
  background-color: #ff7043 !important; }

.deep-orange-text.text-lighten-1 {
  color: #ff7043 !important; }

.deep-orange.darken-1 {
  background-color: #f4511e !important; }

.deep-orange-text.text-darken-1 {
  color: #f4511e !important; }

.deep-orange.darken-2, .deep-orange.btn-delete {
  background-color: #e64a19 !important; }

.deep-orange-text.text-darken-2 {
  color: #e64a19 !important; }

.deep-orange.darken-3 {
  background-color: #d84315 !important; }

.deep-orange-text.text-darken-3 {
  color: #d84315 !important; }

.deep-orange.darken-4 {
  background-color: #bf360c !important; }

.deep-orange-text.text-darken-4 {
  color: #bf360c !important; }

.deep-orange.accent-1 {
  background-color: #ff9e80 !important; }

.deep-orange-text.text-accent-1 {
  color: #ff9e80 !important; }

.deep-orange.accent-2 {
  background-color: #ff6e40 !important; }

.deep-orange-text.text-accent-2 {
  color: #ff6e40 !important; }

.deep-orange.accent-3 {
  background-color: #ff3d00 !important; }

.deep-orange-text.text-accent-3 {
  color: #ff3d00 !important; }

.deep-orange.accent-4 {
  background-color: #dd2c00 !important; }

.deep-orange-text.text-accent-4 {
  color: #dd2c00 !important; }

.brown {
  background-color: #795548 !important; }

.brown-text {
  color: #795548 !important; }

.brown.lighten-5 {
  background-color: #efebe9 !important; }

.brown-text.text-lighten-5 {
  color: #efebe9 !important; }

.brown.lighten-4 {
  background-color: #d7ccc8 !important; }

.brown-text.text-lighten-4 {
  color: #d7ccc8 !important; }

.brown.lighten-3 {
  background-color: #bcaaa4 !important; }

.brown-text.text-lighten-3 {
  color: #bcaaa4 !important; }

.brown.lighten-2 {
  background-color: #a1887f !important; }

.brown-text.text-lighten-2 {
  color: #a1887f !important; }

.brown.lighten-1 {
  background-color: #8d6e63 !important; }

.brown-text.text-lighten-1 {
  color: #8d6e63 !important; }

.brown.darken-1 {
  background-color: #6d4c41 !important; }

.brown-text.text-darken-1 {
  color: #6d4c41 !important; }

.brown.darken-2, .brown.btn-delete {
  background-color: #5d4037 !important; }

.brown-text.text-darken-2 {
  color: #5d4037 !important; }

.brown.darken-3 {
  background-color: #4e342e !important; }

.brown-text.text-darken-3 {
  color: #4e342e !important; }

.brown.darken-4 {
  background-color: #3e2723 !important; }

.brown-text.text-darken-4 {
  color: #3e2723 !important; }

.blue-grey {
  background-color: #607d8b !important; }

.blue-grey-text {
  color: #607d8b !important; }

.blue-grey.lighten-5 {
  background-color: #eceff1 !important; }

.blue-grey-text.text-lighten-5 {
  color: #eceff1 !important; }

.blue-grey.lighten-4 {
  background-color: #cfd8dc !important; }

.blue-grey-text.text-lighten-4 {
  color: #cfd8dc !important; }

.blue-grey.lighten-3 {
  background-color: #b0bec5 !important; }

.blue-grey-text.text-lighten-3 {
  color: #b0bec5 !important; }

.blue-grey.lighten-2 {
  background-color: #90a4ae !important; }

.blue-grey-text.text-lighten-2 {
  color: #90a4ae !important; }

.blue-grey.lighten-1 {
  background-color: #78909c !important; }

.blue-grey-text.text-lighten-1 {
  color: #78909c !important; }

.blue-grey.darken-1 {
  background-color: #546e7a !important; }

.blue-grey-text.text-darken-1 {
  color: #546e7a !important; }

.blue-grey.darken-2, .blue-grey.btn-delete {
  background-color: #455a64 !important; }

.blue-grey-text.text-darken-2 {
  color: #455a64 !important; }

.blue-grey.darken-3 {
  background-color: #37474f !important; }

.blue-grey-text.text-darken-3 {
  color: #37474f !important; }

.blue-grey.darken-4 {
  background-color: #263238 !important; }

.blue-grey-text.text-darken-4 {
  color: #263238 !important; }

.grey {
  background-color: #9e9e9e !important; }

.grey-text {
  color: #9e9e9e !important; }

.grey.lighten-5 {
  background-color: #fafafa !important; }

.grey-text.text-lighten-5 {
  color: #fafafa !important; }

.grey.lighten-4 {
  background-color: #f5f5f5 !important; }

.grey-text.text-lighten-4 {
  color: #f5f5f5 !important; }

.grey.lighten-3 {
  background-color: #eeeeee !important; }

.grey-text.text-lighten-3 {
  color: #eeeeee !important; }

.grey.lighten-2 {
  background-color: #e0e0e0 !important; }

.grey-text.text-lighten-2 {
  color: #e0e0e0 !important; }

.grey.lighten-1 {
  background-color: #bdbdbd !important; }

.grey-text.text-lighten-1 {
  color: #bdbdbd !important; }

.grey.darken-1 {
  background-color: #757575 !important; }

.grey-text.text-darken-1 {
  color: #757575 !important; }

.grey.darken-2, .grey.btn-delete {
  background-color: #616161 !important; }

.grey-text.text-darken-2 {
  color: #616161 !important; }

.grey.darken-3 {
  background-color: #424242 !important; }

.grey-text.text-darken-3 {
  color: #424242 !important; }

.grey.darken-4 {
  background-color: #212121 !important; }

.grey-text.text-darken-4 {
  color: #212121 !important; }

.shades.black {
  background-color: #000000 !important; }

.shades-text.text-black {
  color: #000000 !important; }

.shades.white {
  background-color: #FFFFFF !important; }

.shades-text.text-white {
  color: #FFFFFF !important; }

.shades.transparent {
  background-color: transparent !important; }

.shades-text.text-transparent {
  color: transparent !important; }

.black {
  background-color: #000000 !important; }

.black-text {
  color: #000000 !important; }

.white {
  background-color: #FFFFFF !important; }

.white-text {
  color: #FFFFFF !important; }

.transparent {
  background-color: transparent !important; }

.transparent-text {
  color: transparent !important; }

/* ==========================================================================
   Materialize variables
   ========================================================================== */
/**
 * Table of Contents:
 *
 *  1. Colors
 *  2. Badges
 *  3. Buttons
 *  4. Cards
 *  5. Collapsible
 *  6. Chips
 *  7. Date Picker
 *  8. Dropdown
 *  10. Forms
 *  11. Global
 *  12. Grid
 *  13. Navigation Bar
 *  14. Side Navigation
 *  15. Photo Slider
 *  16. Spinners | Loaders
 *  17. Tabs
 *  18. Tables
 *  19. Toasts
 *  20. Typography
 *  21. Footer
 *  22. Flow Text
 *  23. Collections
 *  24. Progress Bar
 */
/* 1. Colors
   ========================================================================== */
/* 2. Badges
   ========================================================================== */
/* 3. Buttons
   ========================================================================== */
/* 4. Cards
   ========================================================================== */
/* 5. Collapsible
   ========================================================================== */
/* 6. Chips
   ========================================================================== */
/* 7. Date Picker
   ========================================================================== */
/* 8. Dropdown
   ========================================================================== */
/* 9. Fonts
   ========================================================================== */
/* 10. Forms
   ========================================================================== */
/* 11. Global
   ========================================================================== */
/* 12. Grid
   ========================================================================== */
/* 13. Navigation Bar
   ========================================================================== */
/* 14. Side Navigation
   ========================================================================== */
/* 15. Photo Slider
   ========================================================================== */
/* 16. Spinners | Loaders
   ========================================================================== */
/* 17. Tabs
   ========================================================================== */
/* 18. Tables
   ========================================================================== */
/* 19. Toasts
   ========================================================================== */
/* 20. Typography
   ========================================================================== */
/* 21. Footer
   ========================================================================== */
/* 22. Flow Text
   ========================================================================== */
/* 23. Collections
   ========================================================================== */
/* 24. Progress Bar
   ========================================================================== */
/*! normalize.css v3.0.2 | MIT License | git.io/normalize */
/**
 * 1. Set default font family to sans-serif.
 * 2. Prevent iOS text size adjust after orientation change, without disabling
 *    user zoom.
 */
html {
  font-family: sans-serif;
  /* 1 */
  -ms-text-size-adjust: 100%;
  /* 2 */
  -webkit-text-size-adjust: 100%;
  /* 2 */ }

/**
 * Remove default margin.
 */
body {
  margin: 0; }

/* HTML5 display definitions
   ========================================================================== */
/**
 * Correct `block` display not defined for any HTML5 element in IE 8/9.
 * Correct `block` display not defined for `details` or `summary` in IE 10/11
 * and Firefox.
 * Correct `block` display not defined for `main` in IE 11.
 */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
  display: block; }

/**
 * 1. Correct `inline-block` display not defined in IE 8/9.
 * 2. Normalize vertical alignment of `progress` in Chrome, Firefox, and Opera.
 */
audio,
canvas,
progress,
video {
  display: inline-block;
  /* 1 */
  vertical-align: baseline;
  /* 2 */ }

/**
 * Prevent modern browsers from displaying `audio` without controls.
 * Remove excess height in iOS 5 devices.
 */
audio:not([controls]) {
  display: none;
  height: 0; }

/**
 * Address `[hidden]` styling not present in IE 8/9/10.
 * Hide the `template` element in IE 8/9/11, Safari, and Firefox < 22.
 */
[hidden],
template {
  display: none; }

/* Links
   ========================================================================== */
/**
 * Remove the gray background color from active links in IE 10.
 */
a {
  background-color: transparent; }

/**
 * Improve readability when focused and also mouse hovered in all browsers.
 */
a:active,
a:hover {
  outline: 0; }

/* Text-level semantics
   ========================================================================== */
/**
 * Address styling not present in IE 8/9/10/11, Safari, and Chrome.
 */
abbr[title] {
  border-bottom: 1px dotted; }

/**
 * Address style set to `bolder` in Firefox 4+, Safari, and Chrome.
 */
b,
strong {
  font-weight: bold; }

/**
 * Address styling not present in Safari and Chrome.
 */
dfn {
  font-style: italic; }

/**
 * Address variable `h1` font-size and margin within `section` and `article`
 * contexts in Firefox 4+, Safari, and Chrome.
 */
h1 {
  font-size: 2em;
  margin: 0.67em 0; }

/**
 * Address styling not present in IE 8/9.
 */
mark {
  background: #ff0;
  color: #000; }

/**
 * Address inconsistent and variable font size in all browsers.
 */
small {
  font-size: 80%; }

/**
 * Prevent `sub` and `sup` affecting `line-height` in all browsers.
 */
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline; }

sup {
  top: -0.5em; }

sub {
  bottom: -0.25em; }

/* Embedded content
   ========================================================================== */
/**
 * Remove border when inside `a` element in IE 8/9/10.
 */
img {
  border: 0; }

/**
 * Correct overflow not hidden in IE 9/10/11.
 */
svg:not(:root) {
  overflow: hidden; }

/* Grouping content
   ========================================================================== */
/**
 * Address margin not present in IE 8/9 and Safari.
 */
figure {
  margin: 1em 40px; }

/**
 * Address differences between Firefox and other browsers.
 */
hr {
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  height: 0; }

/**
 * Contain overflow in all browsers.
 */
pre {
  overflow: auto; }

/**
 * Address odd `em`-unit font size rendering in all browsers.
 */
code,
kbd,
pre,
samp {
  font-family: monospace, monospace;
  font-size: 1em; }

/* Forms
   ========================================================================== */
/**
 * Known limitation: by default, Chrome and Safari on OS X allow very limited
 * styling of `select`, unless a `border` property is set.
 */
/**
 * 1. Correct color not being inherited.
 *    Known issue: affects color of disabled elements.
 * 2. Correct font properties not being inherited.
 * 3. Address margins set differently in Firefox 4+, Safari, and Chrome.
 */
button,
input,
optgroup,
select,
textarea {
  color: inherit;
  /* 1 */
  font: inherit;
  /* 2 */
  margin: 0;
  /* 3 */ }

/**
 * Address `overflow` set to `hidden` in IE 8/9/10/11.
 */
button {
  overflow: visible; }

/**
 * Address inconsistent `text-transform` inheritance for `button` and `select`.
 * All other form control elements do not inherit `text-transform` values.
 * Correct `button` style inheritance in Firefox, IE 8/9/10/11, and Opera.
 * Correct `select` style inheritance in Firefox.
 */
button,
select {
  text-transform: none; }

/**
 * 1. Avoid the WebKit bug in Android 4.0.* where (2) destroys native `audio`
 *    and `video` controls.
 * 2. Correct inability to style clickable `input` types in iOS.
 * 3. Improve usability and consistency of cursor style between image-type
 *    `input` and others.
 */
/* 1 */
html input[type="button"],
button,
input[type="reset"],
input[type="submit"] {
  -webkit-appearance: button;
  /* 2 */
  cursor: pointer;
  /* 3 */ }

/**
 * Re-set default cursor for disabled elements.
 */
button[disabled],
html input[disabled] {
  cursor: default; }

/**
 * Remove inner padding and border in Firefox 4+.
 */
button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0; }

/**
 * Address Firefox 4+ setting `line-height` on `input` using `!important` in
 * the UA stylesheet.
 */
input {
  line-height: normal; }

/**
 * It's recommended that you don't attempt to style these elements.
 * Firefox's implementation doesn't respect box-sizing, padding, or width.
 *
 * 1. Address box sizing set to `content-box` in IE 8/9/10.
 * 2. Remove excess padding in IE 8/9/10.
 */
input[type="checkbox"],
input[type="radio"] {
  box-sizing: border-box;
  /* 1 */
  padding: 0;
  /* 2 */ }

/**
 * Fix the cursor style for Chrome's increment/decrement buttons. For certain
 * `font-size` values of the `input`, it causes the cursor style of the
 * decrement button to change from `default` to `text`.
 */
input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
  height: auto; }

/**
 * 1. Address `appearance` set to `searchfield` in Safari and Chrome.
 * 2. Address `box-sizing` set to `border-box` in Safari and Chrome
 *    (include `-moz` to future-proof).
 */
input[type="search"] {
  -webkit-appearance: textfield;
  /* 1 */
  -moz-box-sizing: content-box;
  -webkit-box-sizing: content-box;
  /* 2 */
  box-sizing: content-box; }

/**
 * Remove inner padding and search cancel button in Safari and Chrome on OS X.
 * Safari (but not Chrome) clips the cancel button when the search input has
 * padding (and `textfield` appearance).
 */
input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none; }

/**
 * Define consistent border, margin, and padding.
 */
fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em; }

/**
 * 1. Correct `color` not being inherited in IE 8/9/10/11.
 * 2. Remove padding so people aren't caught out if they zero out fieldsets.
 */
legend {
  border: 0;
  /* 1 */
  padding: 0;
  /* 2 */ }

/**
 * Remove default vertical scrollbar in IE 8/9/10/11.
 */
textarea {
  overflow: auto; }

/**
 * Don't inherit the `font-weight` (applied by a rule above).
 * NOTE: the default cannot safely be changed in Chrome and Safari on OS X.
 */
optgroup {
  font-weight: bold; }

/* Tables
   ========================================================================== */
/**
 * Remove most spacing between table cells.
 */
table {
  border-collapse: collapse;
  border-spacing: 0; }

td,
th {
  padding: 0; }

html {
  box-sizing: border-box; }

*, *:before, *:after {
  box-sizing: inherit; }

ul {
  list-style-type: none; }
  ul.browser-default {
    list-style-type: initial; }

a {
  color: #3c813f;
  text-decoration: none;
  -webkit-tap-highlight-color: transparent; }

.valign-wrapper {
  display: flex;
  align-items: center; }
  .valign-wrapper .valign {
    display: block; }

ul {
  padding: 0; }
  ul li {
    list-style-type: none; }

.clearfix {
  clear: both; }

.z-depth-0 {
  box-shadow: none !important; }

.z-depth-1, .btn, .btn-large, .btn-delete, .btn-floating, .dropdown-content, .collapsible {
  box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.16), 0 2px 10px 0 rgba(0, 0, 0, 0.12); }

.z-depth-1-half, .btn:hover, .btn-large:hover, .btn-delete:hover, .btn-floating:hover {
  box-shadow: 0 5px 11px 0 rgba(0, 0, 0, 0.18), 0 4px 15px 0 rgba(0, 0, 0, 0.15); }

.z-depth-2 {
  box-shadow: 0 8px 17px 0 rgba(0, 0, 0, 0.2), 0 6px 20px 0 rgba(0, 0, 0, 0.19); }

.z-depth-3 {
  box-shadow: 0 12px 15px 0 rgba(0, 0, 0, 0.24), 0 17px 50px 0 rgba(0, 0, 0, 0.19); }

.z-depth-4 {
  box-shadow: 0 16px 28px 0 rgba(0, 0, 0, 0.22), 0 25px 55px 0 rgba(0, 0, 0, 0.21); }

.z-depth-5 {
  box-shadow: 0 27px 24px 0 rgba(0, 0, 0, 0.2), 0 40px 77px 0 rgba(0, 0, 0, 0.22); }

.hoverable {
  transition: box-shadow .25s;
  box-shadow: 0; }

.hoverable:hover {
  transition: box-shadow .25s;
  box-shadow: 0 8px 17px 0 rgba(0, 0, 0, 0.2), 0 6px 20px 0 rgba(0, 0, 0, 0.19); }

.divider {
  height: 1px;
  overflow: hidden;
  background-color: #e0e0e0; }

blockquote {
  margin: 20px 0;
  padding-left: 1.5rem;
  border-left: 5px solid #3c813f; }

i {
  line-height: inherit; }
  i.left {
    float: left;
    margin-right: 15px; }
  i.right {
    float: right;
    margin-left: 15px; }
  i.tiny {
    font-size: 1rem; }
  i.small {
    font-size: 2rem; }
  i.medium {
    font-size: 4rem; }
  i.large {
    font-size: 6rem; }

img.responsive-img,
video.responsive-video {
  max-width: 100%;
  height: auto; }

.pagination li {
  display: inline-block;
  font-size: 1.2rem;
  padding: 0 10px;
  line-height: 30px;
  border-radius: 2px;
  text-align: center; }
  .pagination li a {
    color: #444; }
  .pagination li.active a {
    color: #fff; }
  .pagination li.active {
    background-color: #3c813f; }
  .pagination li.disabled a {
    cursor: default;
    color: #999; }
  .pagination li i {
    font-size: 2.2rem;
    vertical-align: middle; }

.pagination li.pages ul li {
  display: inline-block;
  float: none; }

@media only screen and (max-width: 992px) {
  .pagination {
    width: 100%; }
    .pagination li.prev,
    .pagination li.next {
      width: 10%; }
    .pagination li.pages {
      width: 80%;
      overflow: hidden;
      white-space: nowrap; } }

.breadcrumb {
  font-size: 18px;
  color: rgba(255, 255, 255, 0.7); }
  .breadcrumb i,
  .breadcrumb [class^="mdi-"], .breadcrumb [class*="mdi-"],
  .breadcrumb i.material-icons,
  .breadcrumb .le-paste i.le-meta::before, .le-paste
  .breadcrumb i.le-meta::before {
    display: inline-block;
    float: left;
    font-size: 24px; }
  .breadcrumb:before {
    content: '\E5CC';
    color: rgba(255, 255, 255, 0.7);
    vertical-align: top;
    display: inline-block;
    font-family: 'Material Icons';
    font-weight: normal;
    font-style: normal;
    font-size: 25px;
    margin: 0 10px 0 8px;
    -webkit-font-smoothing: antialiased; }
  .breadcrumb:first-child:before {
    display: none; }
  .breadcrumb:last-child {
    color: #fff; }

.parallax-container {
  position: relative;
  overflow: hidden;
  height: 500px; }

.parallax {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  z-index: -1; }
  .parallax img {
    display: none;
    position: absolute;
    left: 50%;
    bottom: 0;
    min-width: 100%;
    min-height: 100%;
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
    transform: translateX(-50%); }

.pin-top, .pin-bottom {
  position: relative; }

.pinned {
  position: fixed !important; }

/*********************
  Transition Classes
**********************/
ul.staggered-list li {
  opacity: 0; }

.fade-in {
  opacity: 0;
  transform-origin: 0 50%; }

/*********************
  Media Query Classes
**********************/
@media only screen and (max-width: 600px) {
  .hide-on-small-only, .hide-on-small-and-down {
    display: none !important; } }

@media only screen and (max-width: 992px) {
  .hide-on-med-and-down {
    display: none !important; } }

@media only screen and (min-width: 601px) {
  .hide-on-med-and-up {
    display: none !important; } }

@media only screen and (min-width: 600px) and (max-width: 992px) {
  .hide-on-med-only {
    display: none !important; } }

@media only screen and (min-width: 993px) {
  .hide-on-large-only, a.toggle-main-menu {
    display: none !important; } }

@media only screen and (min-width: 993px) {
  .show-on-large {
    display: block !important; } }

@media only screen and (min-width: 600px) and (max-width: 992px) {
  .show-on-medium {
    display: block !important; } }

@media only screen and (max-width: 600px) {
  .show-on-small {
    display: block !important; } }

@media only screen and (min-width: 601px) {
  .show-on-medium-and-up {
    display: block !important; } }

@media only screen and (max-width: 992px) {
  .show-on-medium-and-down {
    display: block !important; } }

@media only screen and (max-width: 600px) {
  .center-on-small-only {
    text-align: center; } }

footer.page-footer {
  margin-top: 20px;
  padding-top: 20px;
  background-color: #3c813f; }
  footer.page-footer .footer-copyright {
    overflow: hidden;
    height: 50px;
    line-height: 50px;
    color: rgba(255, 255, 255, 0.8);
    background-color: rgba(51, 51, 51, 0.08); }

table, th, td {
  border: none; }

table {
  width: 100%;
  display: table; }
  table.bordered > thead > tr,
  table.bordered > tbody > tr {
    border-bottom: 1px solid #d0d0d0; }
  table.striped > tbody > tr:nth-child(odd) {
    background-color: #f2f2f2; }
  table.striped > tbody > tr > td {
    border-radius: 0px; }
  table.highlight > tbody > tr {
    transition: background-color .25s ease; }
    table.highlight > tbody > tr:hover {
      background-color: #f2f2f2; }
  table.centered thead tr th, table.centered tbody tr td {
    text-align: center; }

thead {
  border-bottom: 1px solid #d0d0d0; }

td,
th {
  padding: 15px 5px;
  display: table-cell;
  text-align: left;
  vertical-align: middle;
  border-radius: 2px; }

@media only screen and (max-width: 992px) {
  table.responsive-table {
    width: 100%;
    border-collapse: collapse;
    border-spacing: 0;
    display: block;
    position: relative;
    /* sort out borders */ }
    table.responsive-table th,
    table.responsive-table td {
      margin: 0;
      vertical-align: top; }
    table.responsive-table th {
      text-align: left; }
    table.responsive-table thead {
      display: block;
      float: left; }
      table.responsive-table thead tr {
        display: block;
        padding: 0 10px 0 0; }
        table.responsive-table thead tr th::before {
          content: "\00a0"; }
    table.responsive-table tbody {
      display: block;
      width: auto;
      position: relative;
      overflow-x: auto;
      white-space: nowrap; }
      table.responsive-table tbody tr {
        display: inline-block;
        vertical-align: top; }
    table.responsive-table th {
      display: block;
      text-align: right; }
    table.responsive-table td {
      display: block;
      min-height: 1.25em;
      text-align: left; }
    table.responsive-table tr {
      padding: 0 10px; }
    table.responsive-table thead {
      border: 0;
      border-right: 1px solid #d0d0d0; }
    table.responsive-table.bordered th {
      border-bottom: 0;
      border-left: 0; }
    table.responsive-table.bordered td {
      border-left: 0;
      border-right: 0;
      border-bottom: 0; }
    table.responsive-table.bordered tr {
      border: 0; }
    table.responsive-table.bordered tbody tr {
      border-right: 1px solid #d0d0d0; } }

.collection {
  margin: 0.5rem 0 1rem 0;
  border: 1px solid #e3e3e3;
  border-radius: 2px;
  overflow: hidden;
  position: relative; }
  .collection .collection-item {
    background-color: #fff;
    line-height: 1.5rem;
    padding: 10px 20px;
    margin: 0;
    border-bottom: 1px solid #e3e3e3; }
    .collection .collection-item.avatar {
      min-height: 84px;
      padding-left: 72px;
      position: relative; }
      .collection .collection-item.avatar .circle {
        position: absolute;
        width: 42px;
        height: 42px;
        overflow: hidden;
        left: 15px;
        display: inline-block;
        vertical-align: middle; }
      .collection .collection-item.avatar i.circle {
        font-size: 18px;
        line-height: 42px;
        color: #fff;
        background-color: #999;
        text-align: center; }
      .collection .collection-item.avatar .title {
        font-size: 16px; }
      .collection .collection-item.avatar p {
        margin: 0; }
      .collection .collection-item.avatar .secondary-content {
        position: absolute;
        top: 16px;
        right: 16px; }
    .collection .collection-item:last-child {
      border-bottom: none; }
    .collection .collection-item.active {
      background-color: #2c5e2e;
      color: #c1e2c2; }
      .collection .collection-item.active .secondary-content {
        color: #fff; }
  .collection a.collection-item {
    display: block;
    transition: .25s;
    color: #2c5e2e; }
    .collection a.collection-item:not(.active):hover {
      background-color: #ddd; }
  .collection.with-header .collection-header {
    background-color: #fff;
    border-bottom: 1px solid #e3e3e3;
    padding: 10px 20px; }
  .collection.with-header .collection-item {
    padding-left: 30px; }
  .collection.with-header .collection-item.avatar {
    padding-left: 72px; }

.secondary-content {
  float: right;
  color: #2c5e2e; }

.collapsible .collection {
  margin: 0;
  border: none; }

span.badge {
  min-width: 3rem;
  padding: 0 6px;
  text-align: center;
  font-size: 1rem;
  line-height: inherit;
  color: #757575;
  position: absolute;
  right: 15px;
  box-sizing: border-box; }
  span.badge.new {
    font-weight: 300;
    font-size: 0.8rem;
    color: #fff;
    background-color: #2c5e2e;
    border-radius: 2px; }
  span.badge.new:after {
    content: " new"; }

nav ul a span.badge {
  position: static;
  margin-left: 4px;
  line-height: 0; }

.video-container {
  position: relative;
  padding-bottom: 56.25%;
  height: 0;
  overflow: hidden; }
  .video-container iframe, .video-container object, .video-container embed {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%; }

.progress {
  position: relative;
  height: 4px;
  display: block;
  width: 100%;
  background-color: #8dc98f;
  border-radius: 2px;
  margin: 0.5rem 0 1rem 0;
  overflow: hidden; }
  .progress .determinate {
    position: absolute;
    background-color: inherit;
    top: 0;
    left: 0;
    bottom: 0;
    background-color: #2c5e2e;
    transition: width .3s linear; }
  .progress .indeterminate {
    background-color: #2c5e2e; }
    .progress .indeterminate:before {
      content: '';
      position: absolute;
      background-color: inherit;
      top: 0;
      left: 0;
      bottom: 0;
      will-change: left, right;
      animation: indeterminate 2.1s cubic-bezier(0.65, 0.815, 0.735, 0.395) infinite; }
    .progress .indeterminate:after {
      content: '';
      position: absolute;
      background-color: inherit;
      top: 0;
      left: 0;
      bottom: 0;
      will-change: left, right;
      animation: indeterminate-short 2.1s cubic-bezier(0.165, 0.84, 0.44, 1) infinite;
      animation-delay: 1.15s; }

@keyframes indeterminate {
  0% {
    left: -35%;
    right: 100%; }
  60% {
    left: 100%;
    right: -90%; }
  100% {
    left: 100%;
    right: -90%; } }

@keyframes indeterminate-short {
  0% {
    left: -200%;
    right: 100%; }
  60% {
    left: 107%;
    right: -8%; }
  100% {
    left: 107%;
    right: -8%; } }

/*******************
  Utility Classes
*******************/
.hide {
  display: none !important; }

.left-align {
  text-align: left; }

.right-align {
  text-align: right; }

.center, .center-align {
  text-align: center; }

.left {
  float: left !important; }

.right {
  float: right !important; }

.no-select, input[type=range],
input[type=range] + .thumb {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.circle {
  border-radius: 50%; }

.center-block {
  display: block;
  margin-left: auto;
  margin-right: auto; }

.truncate {
  display: block;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis; }

.no-padding {
  padding: 0 !important; }

@font-face {
  font-family: 'Material Icons';
  font-style: normal;
  font-weight: 400;
  src: url(../../font/material-design-icons/MaterialIcons-Regular.eot);
  /* For IE6-8 */
  src: local("Material Icons"), local("MaterialIcons-Regular"), url(../../font/material-design-icons/MaterialIcons-Regular.woff2) format("woff2"), url(../../font/material-design-icons/MaterialIcons-Regular.woff) format("woff"), url(../../font/material-design-icons/MaterialIcons-Regular.ttf) format("truetype"); }

.material-icons, .le-paste .le-meta::before {
  font-family: 'Material Icons';
  font-weight: normal;
  font-style: normal;
  font-size: 24px;
  /* Preferred icon size */
  display: inline-block;
  width: 1em;
  height: 1em;
  line-height: 1;
  text-transform: none;
  letter-spacing: normal;
  word-wrap: normal;
  /* Support for all WebKit browsers. */
  -webkit-font-smoothing: antialiased;
  /* Support for Safari and Chrome. */
  text-rendering: optimizeLegibility;
  /* Support for Firefox. */
  -moz-osx-font-smoothing: grayscale;
  /* Support for IE. */
  font-feature-settings: 'liga'; }

.container {
  margin: 0 auto;
  max-width: 1280px;
  width: 90%; }

@media only screen and (min-width: 601px) {
  .container {
    width: 85%; } }

@media only screen and (min-width: 993px) {
  .container {
    width: 70%; } }

.container .row {
  margin-left: -0.75rem;
  margin-right: -0.75rem; }

.section {
  padding-top: 1rem;
  padding-bottom: 1rem; }
  .section.no-pad {
    padding: 0; }
  .section.no-pad-bot {
    padding-bottom: 0; }
  .section.no-pad-top {
    padding-top: 0; }

.row {
  margin-left: auto;
  margin-right: auto;
  margin-bottom: 20px; }
  .row:after {
    content: "";
    display: table;
    clear: both; }
  .row .col {
    float: left;
    box-sizing: border-box;
    padding: 0 0.75rem; }
    .row .col[class*="push-"], .row .col[class*="pull-"] {
      position: relative; }
    .row .col.s1 {
      width: 8.33333%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s2 {
      width: 16.66667%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s3 {
      width: 25%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s4 {
      width: 33.33333%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s5 {
      width: 41.66667%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s6 {
      width: 50%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s7 {
      width: 58.33333%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s8 {
      width: 66.66667%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s9 {
      width: 75%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s10 {
      width: 83.33333%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s11 {
      width: 91.66667%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s12 {
      width: 100%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.offset-s1 {
      margin-left: 8.33333%; }
    .row .col.pull-s1 {
      right: 8.33333%; }
    .row .col.push-s1 {
      left: 8.33333%; }
    .row .col.offset-s2 {
      margin-left: 16.66667%; }
    .row .col.pull-s2 {
      right: 16.66667%; }
    .row .col.push-s2 {
      left: 16.66667%; }
    .row .col.offset-s3 {
      margin-left: 25%; }
    .row .col.pull-s3 {
      right: 25%; }
    .row .col.push-s3 {
      left: 25%; }
    .row .col.offset-s4 {
      margin-left: 33.33333%; }
    .row .col.pull-s4 {
      right: 33.33333%; }
    .row .col.push-s4 {
      left: 33.33333%; }
    .row .col.offset-s5 {
      margin-left: 41.66667%; }
    .row .col.pull-s5 {
      right: 41.66667%; }
    .row .col.push-s5 {
      left: 41.66667%; }
    .row .col.offset-s6 {
      margin-left: 50%; }
    .row .col.pull-s6 {
      right: 50%; }
    .row .col.push-s6 {
      left: 50%; }
    .row .col.offset-s7 {
      margin-left: 58.33333%; }
    .row .col.pull-s7 {
      right: 58.33333%; }
    .row .col.push-s7 {
      left: 58.33333%; }
    .row .col.offset-s8 {
      margin-left: 66.66667%; }
    .row .col.pull-s8 {
      right: 66.66667%; }
    .row .col.push-s8 {
      left: 66.66667%; }
    .row .col.offset-s9 {
      margin-left: 75%; }
    .row .col.pull-s9 {
      right: 75%; }
    .row .col.push-s9 {
      left: 75%; }
    .row .col.offset-s10 {
      margin-left: 83.33333%; }
    .row .col.pull-s10 {
      right: 83.33333%; }
    .row .col.push-s10 {
      left: 83.33333%; }
    .row .col.offset-s11 {
      margin-left: 91.66667%; }
    .row .col.pull-s11 {
      right: 91.66667%; }
    .row .col.push-s11 {
      left: 91.66667%; }
    .row .col.offset-s12 {
      margin-left: 100%; }
    .row .col.pull-s12 {
      right: 100%; }
    .row .col.push-s12 {
      left: 100%; }
    @media only screen and (min-width: 601px) {
      .row .col.m1 {
        width: 8.33333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m2 {
        width: 16.66667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m3 {
        width: 25%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m4 {
        width: 33.33333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m5 {
        width: 41.66667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m6 {
        width: 50%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m7 {
        width: 58.33333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m8 {
        width: 66.66667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m9 {
        width: 75%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m10 {
        width: 83.33333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m11 {
        width: 91.66667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m12 {
        width: 100%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.offset-m1 {
        margin-left: 8.33333%; }
      .row .col.pull-m1 {
        right: 8.33333%; }
      .row .col.push-m1 {
        left: 8.33333%; }
      .row .col.offset-m2 {
        margin-left: 16.66667%; }
      .row .col.pull-m2 {
        right: 16.66667%; }
      .row .col.push-m2 {
        left: 16.66667%; }
      .row .col.offset-m3 {
        margin-left: 25%; }
      .row .col.pull-m3 {
        right: 25%; }
      .row .col.push-m3 {
        left: 25%; }
      .row .col.offset-m4 {
        margin-left: 33.33333%; }
      .row .col.pull-m4 {
        right: 33.33333%; }
      .row .col.push-m4 {
        left: 33.33333%; }
      .row .col.offset-m5 {
        margin-left: 41.66667%; }
      .row .col.pull-m5 {
        right: 41.66667%; }
      .row .col.push-m5 {
        left: 41.66667%; }
      .row .col.offset-m6 {
        margin-left: 50%; }
      .row .col.pull-m6 {
        right: 50%; }
      .row .col.push-m6 {
        left: 50%; }
      .row .col.offset-m7 {
        margin-left: 58.33333%; }
      .row .col.pull-m7 {
        right: 58.33333%; }
      .row .col.push-m7 {
        left: 58.33333%; }
      .row .col.offset-m8 {
        margin-left: 66.66667%; }
      .row .col.pull-m8 {
        right: 66.66667%; }
      .row .col.push-m8 {
        left: 66.66667%; }
      .row .col.offset-m9 {
        margin-left: 75%; }
      .row .col.pull-m9 {
        right: 75%; }
      .row .col.push-m9 {
        left: 75%; }
      .row .col.offset-m10 {
        margin-left: 83.33333%; }
      .row .col.pull-m10 {
        right: 83.33333%; }
      .row .col.push-m10 {
        left: 83.33333%; }
      .row .col.offset-m11 {
        margin-left: 91.66667%; }
      .row .col.pull-m11 {
        right: 91.66667%; }
      .row .col.push-m11 {
        left: 91.66667%; }
      .row .col.offset-m12 {
        margin-left: 100%; }
      .row .col.pull-m12 {
        right: 100%; }
      .row .col.push-m12 {
        left: 100%; } }
    @media only screen and (min-width: 993px) {
      .row .col.l1 {
        width: 8.33333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l2 {
        width: 16.66667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l3 {
        width: 25%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l4 {
        width: 33.33333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l5 {
        width: 41.66667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l6 {
        width: 50%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l7 {
        width: 58.33333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l8 {
        width: 66.66667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l9 {
        width: 75%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l10 {
        width: 83.33333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l11 {
        width: 91.66667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l12 {
        width: 100%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.offset-l1 {
        margin-left: 8.33333%; }
      .row .col.pull-l1 {
        right: 8.33333%; }
      .row .col.push-l1 {
        left: 8.33333%; }
      .row .col.offset-l2 {
        margin-left: 16.66667%; }
      .row .col.pull-l2 {
        right: 16.66667%; }
      .row .col.push-l2 {
        left: 16.66667%; }
      .row .col.offset-l3 {
        margin-left: 25%; }
      .row .col.pull-l3 {
        right: 25%; }
      .row .col.push-l3 {
        left: 25%; }
      .row .col.offset-l4 {
        margin-left: 33.33333%; }
      .row .col.pull-l4 {
        right: 33.33333%; }
      .row .col.push-l4 {
        left: 33.33333%; }
      .row .col.offset-l5 {
        margin-left: 41.66667%; }
      .row .col.pull-l5 {
        right: 41.66667%; }
      .row .col.push-l5 {
        left: 41.66667%; }
      .row .col.offset-l6 {
        margin-left: 50%; }
      .row .col.pull-l6 {
        right: 50%; }
      .row .col.push-l6 {
        left: 50%; }
      .row .col.offset-l7 {
        margin-left: 58.33333%; }
      .row .col.pull-l7 {
        right: 58.33333%; }
      .row .col.push-l7 {
        left: 58.33333%; }
      .row .col.offset-l8 {
        margin-left: 66.66667%; }
      .row .col.pull-l8 {
        right: 66.66667%; }
      .row .col.push-l8 {
        left: 66.66667%; }
      .row .col.offset-l9 {
        margin-left: 75%; }
      .row .col.pull-l9 {
        right: 75%; }
      .row .col.push-l9 {
        left: 75%; }
      .row .col.offset-l10 {
        margin-left: 83.33333%; }
      .row .col.pull-l10 {
        right: 83.33333%; }
      .row .col.push-l10 {
        left: 83.33333%; }
      .row .col.offset-l11 {
        margin-left: 91.66667%; }
      .row .col.pull-l11 {
        right: 91.66667%; }
      .row .col.push-l11 {
        left: 91.66667%; }
      .row .col.offset-l12 {
        margin-left: 100%; }
      .row .col.pull-l12 {
        right: 100%; }
      .row .col.push-l12 {
        left: 100%; } }

a {
  text-decoration: none; }

html {
  line-height: 1.5;
  font-family: "Roboto", sans-serif;
  font-weight: normal;
  color: rgba(0, 0, 0, 0.87); }
  @media only screen and (min-width: 0) {
    html {
      font-size: 14px; } }
  @media only screen and (min-width: 992px) {
    html {
      font-size: 14.5px; } }
  @media only screen and (min-width: 1200px) {
    html {
      font-size: 15px; } }

h1, h2, h3, h4, h5, h6 {
  font-weight: 400;
  line-height: 1.1; }

h1 a, h2 a, h3 a, h4 a, h5 a, h6 a {
  font-weight: inherit; }

h1 {
  font-size: 4.2rem;
  line-height: 110%;
  margin: 2.1rem 0 1.68rem 0; }

h2 {
  font-size: 3.56rem;
  line-height: 110%;
  margin: 1.78rem 0 1.424rem 0; }

h3 {
  font-size: 2.92rem;
  line-height: 110%;
  margin: 1.46rem 0 1.168rem 0; }

h4 {
  font-size: 2.28rem;
  line-height: 110%;
  margin: 1.14rem 0 0.912rem 0; }

h5 {
  font-size: 1.64rem;
  line-height: 110%;
  margin: 0.82rem 0 0.656rem 0; }

h6 {
  font-size: 1rem;
  line-height: 110%;
  margin: 0.5rem 0 0.4rem 0; }

em {
  font-style: italic; }

strong {
  font-weight: 500; }

small {
  font-size: 75%; }

.light, footer.page-footer .footer-copyright {
  font-weight: 300; }

.thin {
  font-weight: 200; }

.flow-text {
  font-weight: 300; }
  @media only screen and (min-width: 360px) {
    .flow-text {
      font-size: 1.2rem; } }
  @media only screen and (min-width: 390px) {
    .flow-text {
      font-size: 1.224rem; } }
  @media only screen and (min-width: 420px) {
    .flow-text {
      font-size: 1.248rem; } }
  @media only screen and (min-width: 450px) {
    .flow-text {
      font-size: 1.272rem; } }
  @media only screen and (min-width: 480px) {
    .flow-text {
      font-size: 1.296rem; } }
  @media only screen and (min-width: 510px) {
    .flow-text {
      font-size: 1.32rem; } }
  @media only screen and (min-width: 540px) {
    .flow-text {
      font-size: 1.344rem; } }
  @media only screen and (min-width: 570px) {
    .flow-text {
      font-size: 1.368rem; } }
  @media only screen and (min-width: 600px) {
    .flow-text {
      font-size: 1.392rem; } }
  @media only screen and (min-width: 630px) {
    .flow-text {
      font-size: 1.416rem; } }
  @media only screen and (min-width: 660px) {
    .flow-text {
      font-size: 1.44rem; } }
  @media only screen and (min-width: 690px) {
    .flow-text {
      font-size: 1.464rem; } }
  @media only screen and (min-width: 720px) {
    .flow-text {
      font-size: 1.488rem; } }
  @media only screen and (min-width: 750px) {
    .flow-text {
      font-size: 1.512rem; } }
  @media only screen and (min-width: 780px) {
    .flow-text {
      font-size: 1.536rem; } }
  @media only screen and (min-width: 810px) {
    .flow-text {
      font-size: 1.56rem; } }
  @media only screen and (min-width: 840px) {
    .flow-text {
      font-size: 1.584rem; } }
  @media only screen and (min-width: 870px) {
    .flow-text {
      font-size: 1.608rem; } }
  @media only screen and (min-width: 900px) {
    .flow-text {
      font-size: 1.632rem; } }
  @media only screen and (min-width: 930px) {
    .flow-text {
      font-size: 1.656rem; } }
  @media only screen and (min-width: 960px) {
    .flow-text {
      font-size: 1.68rem; } }
  @media only screen and (max-width: 360px) {
    .flow-text {
      font-size: 1.2rem; } }

.btn, .btn-large, .btn-delete,
.btn-flat {
  border: none;
  border-radius: 2px;
  display: inline-block;
  height: 36px;
  line-height: 36px;
  outline: 0;
  padding: 0 2rem;
  text-transform: uppercase;
  vertical-align: middle;
  -webkit-tap-highlight-color: transparent; }

.btn.disabled, .disabled.btn-large, button.btn[disabled], button[disabled].btn-large, button[disabled].btn-delete, .disabled.btn-delete,
.btn-floating.disabled,
button.btn-floating.btn[disabled],
button.btn-floating[disabled].btn-large,
button.btn-floating[disabled].btn-delete,
.btn-large.disabled,
button.btn-large.btn[disabled],
.btn:disabled .btn-large:disabled, .btn-large:disabled .btn-large:disabled, .btn-delete:disabled .btn-large:disabled,
.btn-floating:disabled {
  background-color: #DFDFDF !important;
  box-shadow: none;
  color: #9F9F9F !important;
  cursor: default; }
  .btn.disabled *, .disabled.btn-large *, button.btn[disabled] *, button[disabled].btn-large *, button[disabled].btn-delete *, .disabled.btn-delete *,
  .btn-floating.disabled *, button.btn-floating.btn[disabled] *, button.btn-floating[disabled].btn-large *, button.btn-floating[disabled].btn-delete *,
  .btn-large.disabled *, button.btn-large.btn[disabled] *,
  .btn:disabled .btn-large:disabled *, .btn-large:disabled .btn-large:disabled *, .btn-delete:disabled .btn-large:disabled *,
  .btn-floating:disabled * {
    pointer-events: none; }
  .btn.disabled:hover, .disabled.btn-large:hover, button.btn[disabled]:hover, button[disabled].btn-large:hover, button[disabled].btn-delete:hover, .disabled.btn-delete:hover,
  .btn-floating.disabled:hover,
  button.btn-floating.btn[disabled]:hover,
  button.btn-floating[disabled].btn-large:hover,
  button.btn-floating[disabled].btn-delete:hover,
  .btn-large.disabled:hover,
  button.btn-large.btn[disabled]:hover,
  .btn:disabled .btn-large:disabled:hover, .btn-large:disabled .btn-large:disabled:hover, .btn-delete:disabled .btn-large:disabled:hover,
  .btn-floating:disabled:hover {
    background-color: #DFDFDF !important;
    color: #9F9F9F !important; }

.btn i, .btn-large i, .btn-delete i,
.btn-floating i,
.btn-large i,
.btn-flat i {
  font-size: 1.3rem;
  line-height: inherit; }

.btn, .btn-large, .btn-delete {
  text-decoration: none;
  color: #fff;
  background-color: #2c5e2e;
  text-align: center;
  letter-spacing: .5px;
  transition: .2s ease-out;
  cursor: pointer; }
  .btn:hover, .btn-large:hover, .btn-delete:hover {
    background-color: #346f37; }

.btn-floating {
  display: inline-block;
  color: #fff;
  position: relative;
  overflow: hidden;
  z-index: 1;
  width: 37px;
  height: 37px;
  line-height: 37px;
  padding: 0;
  background-color: #449248;
  border-radius: 50%;
  transition: .3s;
  cursor: pointer;
  vertical-align: middle; }
  .btn-floating i {
    width: inherit;
    display: inline-block;
    text-align: center;
    color: #fff;
    font-size: 1.6rem;
    line-height: 37px; }
  .btn-floating:hover {
    background-color: #3c813f; }
  .btn-floating:before {
    border-radius: 0; }
  .btn-floating.btn-large {
    width: 55.5px;
    height: 55.5px; }
    .btn-floating.btn-large i {
      line-height: 55.5px; }

button.btn-floating {
  border: none; }

.fixed-action-btn {
  position: fixed;
  right: 23px;
  bottom: 23px;
  padding-top: 15px;
  margin-bottom: 0;
  z-index: 998; }
  .fixed-action-btn.active ul {
    visibility: visible; }
  .fixed-action-btn.horizontal {
    padding: 0 0 0 15px; }
    .fixed-action-btn.horizontal ul {
      text-align: right;
      right: 64px;
      top: 50%;
      transform: translateY(-50%);
      height: 100%;
      left: initial;
      width: 500px;
      /*width 100% only goes to width of button container */ }
      .fixed-action-btn.horizontal ul li {
        display: inline-block;
        margin: 15px 15px 0 0; }
  .fixed-action-btn ul {
    left: 0;
    right: 0;
    text-align: center;
    position: absolute;
    bottom: 64px;
    margin: 0;
    visibility: hidden; }
    .fixed-action-btn ul li {
      margin-bottom: 15px; }
    .fixed-action-btn ul a.btn-floating {
      opacity: 0; }

.btn-flat {
  box-shadow: none;
  background-color: transparent;
  color: #343434;
  cursor: pointer; }
  .btn-flat.disabled, button.btn-flat.btn[disabled], button.btn-flat[disabled].btn-large, button.btn-flat[disabled].btn-delete {
    color: #b3b3b3;
    cursor: default; }

.btn-large {
  height: 54px;
  line-height: 54px; }
  .btn-large i {
    font-size: 1.6rem; }

.btn-block {
  display: block; }

.dropdown-content {
  background-color: #fff;
  margin: 0;
  display: none;
  min-width: 100px;
  max-height: 650px;
  overflow-y: auto;
  opacity: 0;
  position: absolute;
  z-index: 999;
  will-change: width, height; }
  .dropdown-content li {
    clear: both;
    color: rgba(0, 0, 0, 0.87);
    cursor: pointer;
    min-height: 50px;
    line-height: 1.5rem;
    width: 100%;
    text-align: left;
    text-transform: none; }
    .dropdown-content li:hover, .dropdown-content li.active, .dropdown-content li.selected {
      background-color: #eee; }
    .dropdown-content li.active.selected {
      background-color: #e1e1e1; }
    .dropdown-content li.divider {
      min-height: 0;
      height: 1px; }
    .dropdown-content li > a, .dropdown-content li > span {
      font-size: 16px;
      color: #2c5e2e;
      display: block;
      line-height: 22px;
      padding: 14px 16px; }
    .dropdown-content li > span > label {
      top: 1px;
      left: 3px;
      height: 18px; }
    .dropdown-content li > a > i {
      height: inherit;
      line-height: inherit; }

/*!
 * Waves v0.6.0
 * http://fian.my.id/Waves
 *
 * Copyright 2014 Alfiana E. Sibuea and other contributors
 * Released under the MIT license
 * https://github.com/fians/Waves/blob/master/LICENSE
 */
.waves-effect, .btn-delete {
  position: relative;
  cursor: pointer;
  display: inline-block;
  overflow: hidden;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -webkit-tap-highlight-color: transparent;
  vertical-align: middle;
  z-index: 1;
  will-change: opacity, transform;
  transition: all .3s ease-out; }
  .waves-effect .waves-ripple, .btn-delete .waves-ripple {
    position: absolute;
    border-radius: 50%;
    width: 20px;
    height: 20px;
    margin-top: -10px;
    margin-left: -10px;
    opacity: 0;
    background: rgba(0, 0, 0, 0.2);
    transition: all 0.7s ease-out;
    transition-property: transform, opacity;
    transform: scale(0);
    pointer-events: none; }
  .waves-effect.waves-light .waves-ripple, .btn-delete .waves-ripple {
    background-color: rgba(255, 255, 255, 0.45); }
  .waves-effect.waves-red .waves-ripple, .waves-red.btn-delete .waves-ripple {
    background-color: rgba(244, 67, 54, 0.7); }
  .waves-effect.waves-yellow .waves-ripple, .waves-yellow.btn-delete .waves-ripple {
    background-color: rgba(255, 235, 59, 0.7); }
  .waves-effect.waves-orange .waves-ripple, .waves-orange.btn-delete .waves-ripple {
    background-color: rgba(255, 152, 0, 0.7); }
  .waves-effect.waves-purple .waves-ripple, .waves-purple.btn-delete .waves-ripple {
    background-color: rgba(156, 39, 176, 0.7); }
  .waves-effect.waves-green .waves-ripple, .waves-green.btn-delete .waves-ripple {
    background-color: rgba(76, 175, 80, 0.7); }
  .waves-effect.waves-teal .waves-ripple, .waves-teal.btn-delete .waves-ripple {
    background-color: rgba(0, 150, 136, 0.7); }
  .waves-effect input[type="button"], .btn-delete input[type="button"], .waves-effect input[type="reset"], .btn-delete input[type="reset"], .waves-effect input[type="submit"], .btn-delete input[type="submit"] {
    border: 0;
    font-style: normal;
    font-size: inherit;
    text-transform: inherit;
    background: none; }

.waves-notransition {
  transition: none !important; }

.waves-circle {
  transform: translateZ(0);
  -webkit-mask-image: -webkit-radial-gradient(circle, white 100%, black 100%); }

.waves-input-wrapper {
  border-radius: 0.2em;
  vertical-align: bottom; }
  .waves-input-wrapper .waves-button-input {
    position: relative;
    top: 0;
    left: 0;
    z-index: 1; }

.waves-circle {
  text-align: center;
  width: 2.5em;
  height: 2.5em;
  line-height: 2.5em;
  border-radius: 50%;
  -webkit-mask-image: none; }

.waves-block {
  display: block; }

/* Firefox Bug: link not triggered */
a.waves-effect .waves-ripple, a.btn-delete .waves-ripple {
  z-index: -1; }

.collapsible {
  border-top: 1px solid #ddd;
  border-right: 1px solid #ddd;
  border-left: 1px solid #ddd;
  margin: 0.5rem 0 1rem 0; }

.collapsible-header {
  display: block;
  cursor: pointer;
  min-height: 3rem;
  line-height: 3rem;
  padding: 0 1rem;
  background-color: #fff;
  border-bottom: 1px solid #ddd; }
  .collapsible-header i {
    width: 2rem;
    font-size: 1.6rem;
    line-height: 3rem;
    display: block;
    float: left;
    text-align: center;
    margin-right: 1rem; }

.collapsible-body {
  display: none;
  border-bottom: 1px solid #ddd;
  box-sizing: border-box; }
  .collapsible-body p {
    margin: 0;
    padding: 2rem; }

.side-nav .collapsible,
.side-nav.fixed .collapsible {
  border: none;
  box-shadow: none; }
  .side-nav .collapsible li,
  .side-nav.fixed .collapsible li {
    padding: 0; }

.side-nav .collapsible-header,
.side-nav.fixed .collapsible-header {
  background-color: transparent;
  border: none;
  line-height: inherit;
  height: inherit;
  padding: 0 30px; }
  .side-nav .collapsible-header:hover,
  .side-nav.fixed .collapsible-header:hover {
    background-color: rgba(0, 0, 0, 0.05); }
  .side-nav .collapsible-header i,
  .side-nav.fixed .collapsible-header i {
    line-height: inherit; }

.side-nav .collapsible-body,
.side-nav.fixed .collapsible-body {
  border: 0;
  background-color: #fff; }
  .side-nav .collapsible-body li a,
  .side-nav.fixed .collapsible-body li a {
    padding: 0 37.5px 0 45px; }

.collapsible.popout {
  border: none;
  box-shadow: none; }
  .collapsible.popout > li {
    box-shadow: 0 2px 5px 0 rgba(0, 0, 0, 0.16), 0 2px 10px 0 rgba(0, 0, 0, 0.12);
    margin: 0 24px;
    transition: margin 0.35s cubic-bezier(0.25, 0.46, 0.45, 0.94); }
  .collapsible.popout > li.active {
    box-shadow: 0 5px 11px 0 rgba(0, 0, 0, 0.18), 0 4px 15px 0 rgba(0, 0, 0, 0.15);
    margin: 16px 0; }

select:focus {
  outline: 1px solid #a5d5a7; }

button:focus {
  outline: none;
  background-color: #336c35; }

label {
  font-size: 0.8rem;
  color: #9e9e9e; }

/* Text Inputs + Textarea
   ========================================================================== */
/* Style Placeholders */
::-webkit-input-placeholder {
  color: #d1d1d1; }

:-moz-placeholder {
  /* Firefox 18- */
  color: #d1d1d1; }

::-moz-placeholder {
  /* Firefox 19+ */
  color: #d1d1d1; }

:-ms-input-placeholder {
  color: #d1d1d1; }

/* Text inputs */
input:not([type]),
input[type=text],
input[type=password],
input[type=email],
input[type=url],
input[type=time],
input[type=date],
input[type=datetime],
input[type=datetime-local],
input[type=tel],
input[type=number],
input[type=search],
textarea.materialize-textarea {
  background-color: transparent;
  border: none;
  border-bottom: 1px solid #9e9e9e;
  border-radius: 0;
  outline: none;
  height: 2.8rem;
  width: 100%;
  font-size: 1rem;
  margin: 0 0 15px 0;
  padding: 0;
  box-shadow: none;
  box-sizing: content-box;
  transition: all 0.3s; }
  input:not([type]):focus,
  input[type=text]:focus,
  input[type=password]:focus,
  input[type=email]:focus,
  input[type=url]:focus,
  input[type=time]:focus,
  input[type=date]:focus,
  input[type=datetime]:focus,
  input[type=datetime-local]:focus,
  input[type=tel]:focus,
  input[type=number]:focus,
  input[type=search]:focus,
  textarea.materialize-textarea:focus {
    border-bottom: 1px solid #2c5e2e;
    box-shadow: 0 1px 0 0 #2c5e2e; }
  input:not([type]):focus + label,
  input[type=text]:focus + label,
  input[type=password]:focus + label,
  input[type=email]:focus + label,
  input[type=url]:focus + label,
  input[type=time]:focus + label,
  input[type=date]:focus + label,
  input[type=datetime]:focus + label,
  input[type=datetime-local]:focus + label,
  input[type=tel]:focus + label,
  input[type=number]:focus + label,
  input[type=search]:focus + label,
  textarea.materialize-textarea:focus + label {
    color: #2c5e2e; }
  input:not([type]):disabled, input:not([type])[readonly],
  input[type=text]:disabled,
  input[type=text][readonly],
  input[type=password]:disabled,
  input[type=password][readonly],
  input[type=email]:disabled,
  input[type=email][readonly],
  input[type=url]:disabled,
  input[type=url][readonly],
  input[type=time]:disabled,
  input[type=time][readonly],
  input[type=date]:disabled,
  input[type=date][readonly],
  input[type=datetime]:disabled,
  input[type=datetime][readonly],
  input[type=datetime-local]:disabled,
  input[type=datetime-local][readonly],
  input[type=tel]:disabled,
  input[type=tel][readonly],
  input[type=number]:disabled,
  input[type=number][readonly],
  input[type=search]:disabled,
  input[type=search][readonly],
  textarea.materialize-textarea:disabled,
  textarea.materialize-textarea[readonly] {
    color: rgba(0, 0, 0, 0.5);
    border-bottom: 1px dotted rgba(0, 0, 0, 0.5);
    box-shadow: none; }
  input:not([type]):disabled + label,
  input:not([type])[readonly] + label,
  input[type=text]:disabled + label,
  input[type=text][readonly] + label,
  input[type=password]:disabled + label,
  input[type=password][readonly] + label,
  input[type=email]:disabled + label,
  input[type=email][readonly] + label,
  input[type=url]:disabled + label,
  input[type=url][readonly] + label,
  input[type=time]:disabled + label,
  input[type=time][readonly] + label,
  input[type=date]:disabled + label,
  input[type=date][readonly] + label,
  input[type=datetime]:disabled + label,
  input[type=datetime][readonly] + label,
  input[type=datetime-local]:disabled + label,
  input[type=datetime-local][readonly] + label,
  input[type=tel]:disabled + label,
  input[type=tel][readonly] + label,
  input[type=number]:disabled + label,
  input[type=number][readonly] + label,
  input[type=search]:disabled + label,
  input[type=search][readonly] + label,
  textarea.materialize-textarea:disabled + label,
  textarea.materialize-textarea[readonly] + label {
    color: rgba(0, 0, 0, 0.5); }
  input:not([type]).valid, input:not([type]):focus.valid,
  input[type=text].valid,
  input[type=text]:focus.valid,
  input[type=password].valid,
  input[type=password]:focus.valid,
  input[type=email].valid,
  input[type=email]:focus.valid,
  input[type=url].valid,
  input[type=url]:focus.valid,
  input[type=time].valid,
  input[type=time]:focus.valid,
  input[type=date].valid,
  input[type=date]:focus.valid,
  input[type=datetime].valid,
  input[type=datetime]:focus.valid,
  input[type=datetime-local].valid,
  input[type=datetime-local]:focus.valid,
  input[type=tel].valid,
  input[type=tel]:focus.valid,
  input[type=number].valid,
  input[type=number]:focus.valid,
  input[type=search].valid,
  input[type=search]:focus.valid,
  textarea.materialize-textarea.valid,
  textarea.materialize-textarea:focus.valid {
    border-bottom: 1px solid #4CAF50;
    box-shadow: 0 1px 0 0 #4CAF50; }
  input:not([type]).valid + label:after,
  input:not([type]):focus.valid + label:after,
  input[type=text].valid + label:after,
  input[type=text]:focus.valid + label:after,
  input[type=password].valid + label:after,
  input[type=password]:focus.valid + label:after,
  input[type=email].valid + label:after,
  input[type=email]:focus.valid + label:after,
  input[type=url].valid + label:after,
  input[type=url]:focus.valid + label:after,
  input[type=time].valid + label:after,
  input[type=time]:focus.valid + label:after,
  input[type=date].valid + label:after,
  input[type=date]:focus.valid + label:after,
  input[type=datetime].valid + label:after,
  input[type=datetime]:focus.valid + label:after,
  input[type=datetime-local].valid + label:after,
  input[type=datetime-local]:focus.valid + label:after,
  input[type=tel].valid + label:after,
  input[type=tel]:focus.valid + label:after,
  input[type=number].valid + label:after,
  input[type=number]:focus.valid + label:after,
  input[type=search].valid + label:after,
  input[type=search]:focus.valid + label:after,
  textarea.materialize-textarea.valid + label:after,
  textarea.materialize-textarea:focus.valid + label:after {
    content: attr(data-success);
    color: #4CAF50;
    opacity: 1; }
  input:not([type]).invalid, input:not([type]):focus.invalid,
  input[type=text].invalid,
  input[type=text]:focus.invalid,
  input[type=password].invalid,
  input[type=password]:focus.invalid,
  input[type=email].invalid,
  input[type=email]:focus.invalid,
  input[type=url].invalid,
  input[type=url]:focus.invalid,
  input[type=time].invalid,
  input[type=time]:focus.invalid,
  input[type=date].invalid,
  input[type=date]:focus.invalid,
  input[type=datetime].invalid,
  input[type=datetime]:focus.invalid,
  input[type=datetime-local].invalid,
  input[type=datetime-local]:focus.invalid,
  input[type=tel].invalid,
  input[type=tel]:focus.invalid,
  input[type=number].invalid,
  input[type=number]:focus.invalid,
  input[type=search].invalid,
  input[type=search]:focus.invalid,
  textarea.materialize-textarea.invalid,
  textarea.materialize-textarea:focus.invalid {
    border-bottom: 1px solid #F44336;
    box-shadow: 0 1px 0 0 #F44336; }
  input:not([type]).invalid + label:after,
  input:not([type]):focus.invalid + label:after,
  input[type=text].invalid + label:after,
  input[type=text]:focus.invalid + label:after,
  input[type=password].invalid + label:after,
  input[type=password]:focus.invalid + label:after,
  input[type=email].invalid + label:after,
  input[type=email]:focus.invalid + label:after,
  input[type=url].invalid + label:after,
  input[type=url]:focus.invalid + label:after,
  input[type=time].invalid + label:after,
  input[type=time]:focus.invalid + label:after,
  input[type=date].invalid + label:after,
  input[type=date]:focus.invalid + label:after,
  input[type=datetime].invalid + label:after,
  input[type=datetime]:focus.invalid + label:after,
  input[type=datetime-local].invalid + label:after,
  input[type=datetime-local]:focus.invalid + label:after,
  input[type=tel].invalid + label:after,
  input[type=tel]:focus.invalid + label:after,
  input[type=number].invalid + label:after,
  input[type=number]:focus.invalid + label:after,
  input[type=search].invalid + label:after,
  input[type=search]:focus.invalid + label:after,
  textarea.materialize-textarea.invalid + label:after,
  textarea.materialize-textarea:focus.invalid + label:after {
    content: attr(data-error);
    color: #F44336;
    opacity: 1; }
  input:not([type]).validate + label,
  input[type=text].validate + label,
  input[type=password].validate + label,
  input[type=email].validate + label,
  input[type=url].validate + label,
  input[type=time].validate + label,
  input[type=date].validate + label,
  input[type=datetime].validate + label,
  input[type=datetime-local].validate + label,
  input[type=tel].validate + label,
  input[type=number].validate + label,
  input[type=search].validate + label,
  textarea.materialize-textarea.validate + label {
    width: 100%;
    pointer-events: none; }
  input:not([type]) + label:after,
  input[type=text] + label:after,
  input[type=password] + label:after,
  input[type=email] + label:after,
  input[type=url] + label:after,
  input[type=time] + label:after,
  input[type=date] + label:after,
  input[type=datetime] + label:after,
  input[type=datetime-local] + label:after,
  input[type=tel] + label:after,
  input[type=number] + label:after,
  input[type=search] + label:after,
  textarea.materialize-textarea + label:after {
    display: block;
    content: "";
    position: absolute;
    top: 65px;
    opacity: 0;
    transition: .2s opacity ease-out, .2s color ease-out; }

.input-field {
  position: relative;
  margin-top: 1rem; }
  .input-field label {
    color: #9e9e9e;
    position: absolute;
    top: 0.6rem;
    left: 0.75rem;
    font-size: 1rem;
    cursor: text;
    transition: .2s ease-out; }
  .input-field label.active {
    font-size: 0.8rem;
    transform: translateY(-140%); }
  .input-field .prefix {
    position: absolute;
    width: 2.8rem;
    font-size: 2rem;
    transition: color .2s; }
    .input-field .prefix.active {
      color: #2c5e2e; }
  .input-field .prefix ~ input,
  .input-field .prefix ~ textarea {
    margin-left: 3rem;
    width: 92%;
    width: calc(100% - 3rem); }
  .input-field .prefix ~ textarea {
    padding-top: .8rem; }
  .input-field .prefix ~ label {
    margin-left: 3rem; }
  @media only screen and (max-width: 992px) {
    .input-field .prefix ~ input {
      width: 86%;
      width: calc(100% - 3rem); } }
  @media only screen and (max-width: 600px) {
    .input-field .prefix ~ input {
      width: 80%;
      width: calc(100% - 3rem); } }

/* Search Field */
.input-field input[type=search] {
  display: block;
  line-height: inherit;
  padding-left: 4rem;
  width: calc(100% - 4rem); }
  .input-field input[type=search]:focus {
    background-color: #fff;
    border: 0;
    box-shadow: none;
    color: #444; }
    .input-field input[type=search]:focus + label i,
    .input-field input[type=search]:focus ~ .mdi-navigation-close,
    .input-field input[type=search]:focus ~ .material-icons,
    .input-field .le-paste input[type=search]:focus ~ .le-meta::before, .le-paste
    .input-field input[type=search]:focus ~ .le-meta::before {
      color: #444; }
  .input-field input[type=search] + label {
    left: 1rem; }
  .input-field input[type=search] ~ .mdi-navigation-close,
  .input-field input[type=search] ~ .material-icons,
  .input-field .le-paste input[type=search] ~ .le-meta::before, .le-paste
  .input-field input[type=search] ~ .le-meta::before {
    position: absolute;
    top: 0;
    right: 1rem;
    color: transparent;
    cursor: pointer;
    font-size: 2rem;
    transition: .3s color; }

/* Textarea */
textarea {
  width: 100%;
  height: 2.8rem;
  background-color: transparent; }
  textarea.materialize-textarea {
    overflow-y: hidden;
    /* prevents scroll bar flash */
    padding: 1.6rem 0;
    /* prevents text jump on Enter keypress */
    resize: none;
    min-height: 2.8rem; }

.hiddendiv {
  display: none;
  white-space: pre-wrap;
  word-wrap: break-word;
  overflow-wrap: break-word;
  /* future version of deprecated 'word-wrap' */
  padding-top: 1.2rem;
  /* prevents text jump on Enter keypress */ }

/* Radio Buttons
   ========================================================================== */
[type="radio"]:not(:checked),
[type="radio"]:checked {
  position: absolute;
  left: -9999px;
  opacity: 0; }

[type="radio"]:not(:checked) + label,
[type="radio"]:checked + label {
  position: relative;
  padding-left: 35px;
  cursor: pointer;
  display: inline-block;
  height: 25px;
  line-height: 25px;
  font-size: 1rem;
  transition: .28s ease;
  -khtml-user-select: none;
  /* webkit (konqueror) browsers */
  user-select: none; }

[type="radio"] + label:before,
[type="radio"] + label:after {
  content: '';
  position: absolute;
  left: 0;
  top: 0;
  margin: 4px;
  width: 16px;
  height: 16px;
  z-index: 0;
  transition: .28s ease; }

/* Unchecked styles */
[type="radio"]:not(:checked) + label:before,
[type="radio"]:not(:checked) + label:after,
[type="radio"]:checked + label:before,
[type="radio"]:checked + label:after,
[type="radio"].with-gap:checked + label:before,
[type="radio"].with-gap:checked + label:after {
  border-radius: 50%; }

[type="radio"]:not(:checked) + label:before,
[type="radio"]:not(:checked) + label:after {
  border: 2px solid #5a5a5a; }

[type="radio"]:not(:checked) + label:after {
  z-index: -1;
  transform: scale(0); }

/* Checked styles */
[type="radio"]:checked + label:before {
  border: 2px solid transparent; }

[type="radio"]:checked + label:after,
[type="radio"].with-gap:checked + label:before,
[type="radio"].with-gap:checked + label:after {
  border: 2px solid #2c5e2e; }

[type="radio"]:checked + label:after,
[type="radio"].with-gap:checked + label:after {
  background-color: #2c5e2e;
  z-index: 0; }

[type="radio"]:checked + label:after {
  transform: scale(1.02); }

/* Radio With gap */
[type="radio"].with-gap:checked + label:after {
  transform: scale(0.5); }

/* Focused styles */
[type="radio"].tabbed:focus + label:before {
  box-shadow: 0 0 0 10px rgba(0, 0, 0, 0.1); }

/* Disabled Radio With gap */
[type="radio"].with-gap:disabled:checked + label:before {
  border: 2px solid rgba(0, 0, 0, 0.5); }

[type="radio"].with-gap:disabled:checked + label:after {
  border: none;
  background-color: rgba(0, 0, 0, 0.5); }

/* Disabled style */
[type="radio"]:disabled:not(:checked) + label:before,
[type="radio"]:disabled:checked + label:before {
  background-color: transparent;
  border-color: rgba(0, 0, 0, 0.5); }

[type="radio"]:disabled + label {
  color: rgba(0, 0, 0, 0.5); }

[type="radio"]:disabled:not(:checked) + label:before {
  border-color: rgba(0, 0, 0, 0.5); }

[type="radio"]:disabled:checked + label:after {
  background-color: rgba(0, 0, 0, 0.5);
  border-color: #BDBDBD; }

/* Checkboxes
   ========================================================================== */
/* CUSTOM CSS CHECKBOXES */
form p {
  margin-bottom: 10px;
  text-align: left; }

form p:last-child {
  margin-bottom: 0; }

/* Remove default checkbox */
[type="checkbox"]:not(:checked),
[type="checkbox"]:checked {
  position: absolute;
  left: -9999px;
  opacity: 0; }

[type="checkbox"] {
  /* checkbox aspect */ }
  [type="checkbox"] + label {
    position: relative;
    padding-left: 35px;
    cursor: pointer;
    display: inline-block;
    height: 25px;
    line-height: 25px;
    font-size: 1rem;
    -webkit-user-select: none;
    /* webkit (safari, chrome) browsers */
    -moz-user-select: none;
    /* mozilla browsers */
    -khtml-user-select: none;
    /* webkit (konqueror) browsers */
    -ms-user-select: none;
    /* IE10+ */ }
  [type="checkbox"] + label:before,
  [type="checkbox"]:not(.filled-in) + label:after {
    content: '';
    position: absolute;
    top: 0;
    left: 0;
    width: 18px;
    height: 18px;
    z-index: 0;
    border: 2px solid #5a5a5a;
    border-radius: 1px;
    margin-top: 2px;
    transition: .2s; }
  [type="checkbox"]:not(.filled-in) + label:after {
    border: 0;
    transform: scale(0); }
  [type="checkbox"]:not(:checked):disabled + label:before {
    border: none;
    background-color: rgba(0, 0, 0, 0.5); }
  [type="checkbox"].tabbed:focus + label:after {
    transform: scale(1);
    border: 0;
    border-radius: 50%;
    box-shadow: 0 0 0 10px rgba(0, 0, 0, 0.1);
    background-color: rgba(0, 0, 0, 0.1); }

[type="checkbox"]:checked + label:before {
  top: -4px;
  left: -5px;
  width: 12px;
  height: 22px;
  border-top: 2px solid transparent;
  border-left: 2px solid transparent;
  border-right: 2px solid #2c5e2e;
  border-bottom: 2px solid #2c5e2e;
  transform: rotate(40deg);
  backface-visibility: hidden;
  transform-origin: 100% 100%; }

[type="checkbox"]:checked:disabled + label:before {
  border-right: 2px solid rgba(0, 0, 0, 0.5);
  border-bottom: 2px solid rgba(0, 0, 0, 0.5); }

/* Indeterminate checkbox */
[type="checkbox"]:indeterminate + label:before {
  top: -11px;
  left: -12px;
  width: 10px;
  height: 22px;
  border-top: none;
  border-left: none;
  border-right: 2px solid #2c5e2e;
  border-bottom: none;
  transform: rotate(90deg);
  backface-visibility: hidden;
  transform-origin: 100% 100%; }

[type="checkbox"]:indeterminate:disabled + label:before {
  border-right: 2px solid rgba(0, 0, 0, 0.5);
  background-color: transparent; }

[type="checkbox"].filled-in + label:after {
  border-radius: 2px; }

[type="checkbox"].filled-in + label:before,
[type="checkbox"].filled-in + label:after {
  content: '';
  left: 0;
  position: absolute;
  /* .1s delay is for check animation */
  transition: border .25s, background-color .25s, width .20s .1s, height .20s .1s, top .20s .1s, left .20s .1s;
  z-index: 1; }

[type="checkbox"].filled-in:not(:checked) + label:before {
  width: 0;
  height: 0;
  border: 3px solid transparent;
  left: 6px;
  top: 10px;
  -webkit-transform: rotateZ(37deg);
  transform: rotateZ(37deg);
  -webkit-transform-origin: 20% 40%;
  transform-origin: 100% 100%; }

[type="checkbox"].filled-in:not(:checked) + label:after {
  height: 20px;
  width: 20px;
  background-color: transparent;
  border: 2px solid #5a5a5a;
  top: 0px;
  z-index: 0; }

[type="checkbox"].filled-in:checked + label:before {
  top: 0;
  left: 1px;
  width: 8px;
  height: 13px;
  border-top: 2px solid transparent;
  border-left: 2px solid transparent;
  border-right: 2px solid #fff;
  border-bottom: 2px solid #fff;
  -webkit-transform: rotateZ(37deg);
  transform: rotateZ(37deg);
  -webkit-transform-origin: 100% 100%;
  transform-origin: 100% 100%; }

[type="checkbox"].filled-in:checked + label:after {
  top: 0;
  width: 20px;
  height: 20px;
  border: 2px solid #2c5e2e;
  background-color: #2c5e2e;
  z-index: 0; }

[type="checkbox"].filled-in.tabbed:focus + label:after {
  border-radius: 2px;
  border-color: #5a5a5a;
  background-color: rgba(0, 0, 0, 0.1); }

[type="checkbox"].filled-in.tabbed:checked:focus + label:after {
  border-radius: 2px;
  background-color: #2c5e2e;
  border-color: #2c5e2e; }

[type="checkbox"].filled-in:disabled:not(:checked) + label:before {
  background-color: transparent;
  border: 2px solid transparent; }

[type="checkbox"].filled-in:disabled:not(:checked) + label:after {
  border-color: transparent;
  background-color: #BDBDBD; }

[type="checkbox"].filled-in:disabled:checked + label:before {
  background-color: transparent; }

[type="checkbox"].filled-in:disabled:checked + label:after {
  background-color: #BDBDBD;
  border-color: #BDBDBD; }

/* Switch
   ========================================================================== */
.switch,
.switch * {
  -webkit-user-select: none;
  -moz-user-select: none;
  -khtml-user-select: none;
  -ms-user-select: none; }

.switch label {
  cursor: pointer; }

.switch label input[type=checkbox] {
  opacity: 0;
  width: 0;
  height: 0; }
  .switch label input[type=checkbox]:checked + .lever {
    background-color: #779278; }
    .switch label input[type=checkbox]:checked + .lever:after {
      background-color: #2c5e2e;
      left: 24px; }

.switch label .lever {
  content: "";
  display: inline-block;
  position: relative;
  width: 40px;
  height: 15px;
  background-color: #818181;
  border-radius: 15px;
  margin-right: 10px;
  transition: background 0.3s ease;
  vertical-align: middle;
  margin: 0 16px; }
  .switch label .lever:after {
    content: "";
    position: absolute;
    display: inline-block;
    width: 21px;
    height: 21px;
    background-color: #F1F1F1;
    border-radius: 21px;
    box-shadow: 0 1px 3px 1px rgba(0, 0, 0, 0.4);
    left: -5px;
    top: -3px;
    transition: left 0.3s ease, background .3s ease, box-shadow 0.1s ease; }

input[type=checkbox]:checked:not(:disabled) ~ .lever:active::after,
input[type=checkbox]:checked:not(:disabled).tabbed:focus ~ .lever::after {
  box-shadow: 0 1px 3px 1px rgba(0, 0, 0, 0.4), 0 0 0 15px rgba(44, 94, 46, 0.1); }

input[type=checkbox]:not(:disabled) ~ .lever:active:after,
input[type=checkbox]:not(:disabled).tabbed:focus ~ .lever::after {
  box-shadow: 0 1px 3px 1px rgba(0, 0, 0, 0.4), 0 0 0 15px rgba(0, 0, 0, 0.08); }

.switch input[type=checkbox][disabled] + .lever {
  cursor: default; }

.switch label input[type=checkbox][disabled] + .lever:after,
.switch label input[type=checkbox][disabled]:checked + .lever:after {
  background-color: #BDBDBD; }

/* Select Field
   ========================================================================== */
select {
  display: none; }

select.browser-default {
  display: block; }

select {
  background-color: rgba(255, 255, 255, 0.9);
  width: 100%;
  padding: 5px;
  border: 1px solid #f2f2f2;
  border-radius: 2px;
  height: 2.8rem; }

.select-label {
  position: absolute; }

.select-wrapper {
  position: relative; }
  .select-wrapper input.select-dropdown {
    position: relative;
    cursor: pointer;
    background-color: transparent;
    border: none;
    border-bottom: 1px solid #9e9e9e;
    outline: none;
    height: 2.8rem;
    line-height: 2.8rem;
    width: 100%;
    font-size: 1rem;
    margin: 0 0 15px 0;
    padding: 0;
    display: block; }
  .select-wrapper span.caret {
    color: initial;
    position: absolute;
    right: 0;
    top: 16px;
    font-size: 10px; }
    .select-wrapper span.caret.disabled {
      color: rgba(0, 0, 0, 0.5); }
  .select-wrapper + label {
    position: absolute;
    top: -14px;
    font-size: 0.8rem; }

select:disabled {
  color: rgba(0, 0, 0, 0.3); }

.select-wrapper input.select-dropdown:disabled {
  color: rgba(0, 0, 0, 0.3);
  cursor: default;
  -webkit-user-select: none;
  /* webkit (safari, chrome) browsers */
  -moz-user-select: none;
  /* mozilla browsers */
  -ms-user-select: none;
  /* IE10+ */
  border-bottom: 1px solid rgba(0, 0, 0, 0.3); }

.select-wrapper i {
  color: rgba(0, 0, 0, 0.3); }

.select-dropdown li.disabled,
.select-dropdown li.disabled > span,
.select-dropdown li.optgroup {
  color: rgba(0, 0, 0, 0.3);
  background-color: transparent; }

.select-dropdown li img {
  height: 40px;
  width: 40px;
  margin: 5px 15px;
  float: right; }

.select-dropdown li.optgroup {
  border-top: 1px solid #eee; }
  .select-dropdown li.optgroup.selected > span {
    color: rgba(0, 0, 0, 0.7); }
  .select-dropdown li.optgroup > span {
    color: rgba(0, 0, 0, 0.4); }
  .select-dropdown li.optgroup ~ li:not(.optgroup) {
    padding-left: 1rem; }

/* File Input
   ========================================================================== */
.file-field {
  position: relative; }
  .file-field .file-path-wrapper {
    overflow: hidden;
    padding-left: 10px; }
  .file-field input.file-path {
    width: 100%; }
  .file-field .btn, .file-field .btn-large, .file-field .btn-delete {
    float: left;
    height: 2.8rem;
    line-height: 2.8rem; }
  .file-field span {
    cursor: pointer; }
  .file-field input[type=file] {
    position: absolute;
    top: 0;
    right: 0;
    left: 0;
    bottom: 0;
    width: 100%;
    margin: 0;
    padding: 0;
    font-size: 20px;
    cursor: pointer;
    opacity: 0;
    filter: alpha(opacity=0); }

/* Range
   ========================================================================== */
.range-field {
  position: relative; }

input[type=range],
input[type=range] + .thumb {
  cursor: pointer; }

input[type=range] {
  position: relative;
  background-color: transparent;
  border: none;
  outline: none;
  width: 100%;
  margin: 15px 0;
  padding: 0; }
  input[type=range]:focus {
    outline: none; }

input[type=range] + .thumb {
  position: absolute;
  border: none;
  height: 0;
  width: 0;
  border-radius: 50%;
  background-color: #2c5e2e;
  top: 10px;
  margin-left: -6px;
  transform-origin: 50% 50%;
  transform: rotate(-45deg); }
  input[type=range] + .thumb .value {
    display: block;
    width: 30px;
    text-align: center;
    color: #2c5e2e;
    font-size: 0;
    transform: rotate(45deg); }
  input[type=range] + .thumb.active {
    border-radius: 50% 50% 50% 0; }
    input[type=range] + .thumb.active .value {
      color: #fff;
      margin-left: -1px;
      margin-top: 8px;
      font-size: 10px; }

input[type=range] {
  -webkit-appearance: none; }

input[type=range]::-webkit-slider-runnable-track {
  height: 3px;
  background: #c2c0c2;
  border: none; }

input[type=range]::-webkit-slider-thumb {
  -webkit-appearance: none;
  border: none;
  height: 14px;
  width: 14px;
  border-radius: 50%;
  background-color: #2c5e2e;
  transform-origin: 50% 50%;
  margin: -5px 0 0 0;
  transition: .3s; }

input[type=range]:focus::-webkit-slider-runnable-track {
  background: #ccc; }

input[type=range] {
  /* fix for FF unable to apply focus style bug  */
  border: 1px solid white;
  /*required for proper track sizing in FF*/ }

input[type=range]::-moz-range-track {
  height: 3px;
  background: #ddd;
  border: none; }

input[type=range]::-moz-range-thumb {
  border: none;
  height: 14px;
  width: 14px;
  border-radius: 50%;
  background: #2c5e2e;
  margin-top: -5px; }

input[type=range]:-moz-focusring {
  outline: 1px solid #fff;
  outline-offset: -1px; }

input[type=range]:focus::-moz-range-track {
  background: #ccc; }

input[type=range]::-ms-track {
  height: 3px;
  background: transparent;
  border-color: transparent;
  border-width: 6px 0;
  /*remove default tick marks*/
  color: transparent; }

input[type=range]::-ms-fill-lower {
  background: #777; }

input[type=range]::-ms-fill-upper {
  background: #ddd; }

input[type=range]::-ms-thumb {
  border: none;
  height: 14px;
  width: 14px;
  border-radius: 50%;
  background: #2c5e2e; }

input[type=range]:focus::-ms-fill-lower {
  background: #888; }

input[type=range]:focus::-ms-fill-upper {
  background: #ccc; }

@keyframes background-position {
  0% {
    background-position: 0 0; }
  100% {
    background-position: 100% 0; } }

html, body {
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
  background-color: #fafafa;
  color: #222; }

h1, h2, h3, h4, h5 {
  color: #449248; }

strong {
  font-weight: bold; }

p {
  margin: 1rem 0; }

dl dt {
  margin: 0; }

dl dd {
  margin: 0 0 0.5rem 1rem; }

pre {
  margin: 0;
  padding: 0; }

pre.stylish {
  padding: 0.2rem 0.5rem;
  background: #f0f0f0;
  margin: 0.3rem 0; }

dl.horizontal {
  margin: 0; }
  dl.horizontal dt {
    width: 10em;
    float: left;
    clear: left; }

a:hover {
  color: #1c3b1d; }

svg {
  width: 100%;
  height: auto;
  display: inline-block; }

iframe {
  display: block; }

div.alert, p.alert {
  background: #FFEBEE;
  border: 1px solid #E57373;
  border-radius: 2px;
  color: #D32F2F;
  padding: 10px; }
  div.alert a, p.alert a {
    color: #C62828;
    text-decoration: underline; }
    div.alert a:hover, p.alert a:hover {
      text-decoration: none; }

.col .btn, .col .btn-large, .col .btn-delete, .col .btn-large, .col .btn-flat {
  margin-right: 0.5rem; }
  .col .btn.right, .col .right.btn-large, .col .right.btn-delete, .col .btn-large.right, .col .btn-flat.right {
    margin-right: 0; }

.hidden {
  display: none; }

.input-btn-right .btn, .input-btn-right .btn-large, .input-btn-right .btn-delete {
  float: right;
  margin-right: 0;
  margin-top: 0.5rem; }

.input-btn-right .input-left {
  overflow: hidden;
  padding-right: 0.75rem; }

.select-wrapper ul {
  display: block;
  margin-top: -54px;
  transition: opacity 0.3s ease-in-out;
  left: -2000px; }
  .select-wrapper ul.active {
    opacity: 1;
    left: auto; }

.select-wrapper input.select-dropdown {
  color: #222; }

.dropdown-content li:hover {
  background: #eee; }

.dropdown-content li.disabled:hover {
  background: transparent; }

.dropdown-content li.active {
  background: #e1e1e1; }

#vue_tooltip {
  background-color: #323232;
  color: #fefefe;
  font-size: 1rem;
  line-height: 120%;
  text-align: center;
  border-radius: 4px;
  padding: 8px 6px;
  max-width: calc(100% - 4px);
  min-height: 30px;
  transition: opacity 350ms;
  transition-delay: 100ms;
  position: absolute;
  left: -2000px;
  top: -2000px;
  overflow: hidden;
  opacity: 0;
  z-index: 2000;
  will-change: opacity;
  pointer-events: none; }
  #vue_tooltip.active {
    opacity: 0.95; }
  @media only screen and (max-width: 992px) {
    #vue_tooltip {
      display: none !important; } }

.scroll-element {
  height: 100%;
  overflow: auto; }

.not-logged-in-wrapper {
  padding-top: 3em; }
  .not-logged-in-wrapper h1 {
    text-indent: -10000px;
    max-height: 55px;
    margin: 0;
    background: url(../../images/logo.svg) no-repeat; }
  .not-logged-in-wrapper h2 {
    font-size: 2rem; }
  .not-logged-in-wrapper .about {
    padding-top: 2em; }
    .not-logged-in-wrapper .about, .not-logged-in-wrapper .about a {
      color: #888888; }
    .not-logged-in-wrapper .about a:hover {
      color: #222; }

/*

github.com style (c) Vasily Polovnyov <vast@whiteants.net>

*/
.hljs {
  display: block;
  overflow-x: auto; }

.hljs-comment,
.hljs-quote {
  color: #998;
  font-style: italic; }

.hljs-keyword,
.hljs-selector-tag,
.hljs-subst {
  color: #333;
  font-weight: bold; }

.hljs-number,
.hljs-literal,
.hljs-variable,
.hljs-template-variable,
.hljs-tag .hljs-attr {
  color: #008080; }

.hljs-string,
.hljs-doctag {
  color: #d14; }

.hljs-title,
.hljs-section,
.hljs-selector-id {
  color: #900;
  font-weight: bold; }

.hljs-subst {
  font-weight: normal; }

.hljs-type,
.hljs-class .hljs-title {
  color: #458;
  font-weight: bold; }

.hljs-tag,
.hljs-name,
.hljs-attribute {
  color: #000080;
  font-weight: normal; }

.hljs-regexp,
.hljs-link {
  color: #009926; }

.hljs-symbol,
.hljs-bullet {
  color: #990073; }

.hljs-built_in,
.hljs-builtin-name {
  color: #0086b3; }

.hljs-meta {
  color: #999;
  font-weight: bold; }

.hljs-deletion {
  background: #fdd; }

.hljs-addition {
  background: #dfd; }

.hljs-emphasis {
  font-style: italic; }

.hljs-strong {
  font-weight: bold; }

.convos-create-dialog .autocomplete a {
  padding: 0.3rem 0;
  border-bottom: 1px solid #eee;
  display: block; }
  .convos-create-dialog .autocomplete a:hover {
    background-color: #eee; }
  .convos-create-dialog .autocomplete a.active {
    background-color: #e1e1e1; }

.convos-create-dialog .autocomplete h6 {
  color: #3c813f;
  display: block;
  margin: 0;
  font-weight: bold; }

.convos-create-dialog .autocomplete p {
  color: #484848;
  font-size: 0.9rem;
  margin-top: 0.3rem; }

.convos-create-dialog .autocomplete .badge .material-icons, .convos-create-dialog .autocomplete .badge .le-paste .le-meta::before, .le-paste .convos-create-dialog .autocomplete .badge .le-meta::before {
  font-size: 1.1em;
  vertical-align: middle; }

ul.complete-dropdown {
  margin: 0;
  position: absolute;
  display: block !important;
  opacity: 1 !important;
  max-height: 50vh; }
  ul.complete-dropdown li {
    min-height: auto; }
  ul.complete-dropdown li:hover {
    background: transparent; }
  ul.complete-dropdown li.active:hover {
    background: #eee; }
  ul.complete-dropdown li > a {
    padding: 6px 16px;
    cursor: default; }

.convos-chat {
  position: relative;
  width: 100vw;
  height: 100vh;
  overflow: hidden; }

.convos-dialog-container,
.convos-settings {
  position: relative;
  height: 100%;
  overflow: auto; }

@media only screen and (min-width: 993px) {
  .convos-dialog-container,
  .convos-settings {
    margin-left: 240px; }
  body.has-sidebar .convos-dialog-container, body.has-sidebar .convos-settings {
    margin-right: 320px; } }

.convos-dialog-container main,
.convos-settings main {
  position: absolute;
  top: 56px;
  width: 100%;
  padding: 1.5rem 0.75rem;
  z-index: 10; }
  @media only screen and (min-width: 993px) {
    .convos-dialog-container main,
    .convos-settings main {
      top: 64px; } }

.scroll-element {
  -webkit-overflow-scrolling: touch;
  overflow: auto; }

.convos-dialog-container main {
  height: auto;
  bottom: 46px; }

.convos-dialog-container.inactive {
  display: none; }

.convos-settings main {
  bottom: 0; }

.convos-input {
  background-color: #fafafa;
  border-top: 1px solid #d1d1d1;
  padding: 8px 0.75rem 0 0.75rem;
  width: 100%;
  position: absolute;
  bottom: 0;
  z-index: 899; }
  .convos-input.loading {
    background: repeating-linear-gradient(-45deg, #fafafa, #fafafa 10px, #f2f2f2 10px, #f2f2f2 20px, #fafafa 20px) top left;
    background-position: 0 0;
    background-size: 394px 100%;
    animation: background-position 14s infinite linear; }
    .convos-input.loading ::-webkit-input-placeholder {
      color: #3c813f; }
    .convos-input.loading :-moz-placeholder {
      color: #3c813f; }
    .convos-input.loading ::-moz-placeholder {
      color: #3c813f; }
    .convos-input.loading :-ms-input-placeholder {
      color: #3c813f; }
  .convos-input i {
    font-size: 2rem;
    cursor: pointer;
    width: 2rem;
    float: right;
    transition: color .2s; }
    .convos-input i, .convos-input i.active {
      color: #2c5e2e; }
  .convos-input textarea.materialize-textarea {
    padding: 0;
    margin: 0;
    box-shadow: none;
    width: calc(100% - 2rem);
    height: 24px;
    min-height: 2rem;
    max-height: 9.5rem;
    overflow: auto; }
    .convos-input textarea.materialize-textarea, .convos-input textarea.materialize-textarea:focus {
      border: 0; }

.convos-settings main > div,
.convos-settings main > form {
  max-width: 50em;
  margin-left: 0; }

.convos-settings .divider {
  margin: 2rem 0; }

.convos-message {
  clear: both;
  display: block;
  position: relative;
  padding: 4px 0;
  word-wrap: break-word; }
  .convos-message.error, .convos-message.notice {
    padding-left: 0.75rem;
    border-left: 2px solid #9e9e9e; }
  .convos-message.action .message, .convos-message.action .title {
    font-style: italic;
    display: inline; }
  .convos-message.action .link-embedder {
    font-style: normal; }
  .convos-message.day-changed {
    color: rgba(102, 102, 102, 0.87);
    font-size: 0.8rem;
    text-align: center;
    border-bottom: 1px solid #dbdbdb;
    margin: -0.2rem 0 0.5rem 0;
    height: 0.9rem; }
    .convos-message.day-changed:hover {
      background: transparent; }
    .convos-message.day-changed span {
      background: #fafafa;
      padding: 0 8px;
      line-height: 1rem; }
  .convos-message.error {
    border-left: 2px solid #E57373;
    color: #888888; }
    .convos-message.error a {
      color: #e55454; }
  .convos-message.highlight {
    background-color: #ffd7db;
    margin-left: -0.375rem;
    margin-right: -0.375rem;
    padding-left: 0.375rem;
    padding-right: 0.375rem; }
  .convos-message.action.highlight .message {
    margin-left: 0;
    padding-left: 0; }
  .convos-message.notice {
    border-left: 2px solid #bdbdbd;
    color: #888888; }
    .convos-message.notice a {
      color: #6ab96d; }
  .convos-message.inactive-user, .convos-message.inactive-user .secondary-container {
    color: #888888; }
  .convos-message.inactive-user a.title {
    color: #7bc17e;
    text-decoration: line-through; }
  .convos-message.motd .message {
    font-family: "SFMono-Regular", Consolas, "Liberation Mono", Menlo, monospace;
    font-size: 0.9rem; }
    .convos-message.motd .message div {
      font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", sans-serif;
      font-size: 1rem; }
  .convos-message.same-user {
    margin-top: -4px; }
    .convos-message.same-user .title {
      display: none; }
    .convos-message.same-user .secondary-content {
      opacity: 0;
      transition: opacity 1000ms; }
    .convos-message.same-user:hover .secondary-content {
      display: block;
      opacity: 1;
      color: #888888;
      transition: opacity 300ms; }
  .convos-message.same-user.action .title {
    display: inline; }
  .convos-message .message a {
    color: inherit;
    text-decoration: underline; }
  .convos-message .message a:hover {
    text-decoration: none; }
  .convos-message .message .material-icons, .convos-message .message .le-paste .le-meta::before, .le-paste .convos-message .message .le-meta::before {
    vertical-align: text-top;
    font-size: 18px;
    margin-left: 4px; }
  .convos-message code {
    background: #ededed;
    outline: 1px solid #d4d4d4;
    padding: 1px 3px; }
  .convos-message .secondary-content {
    padding-top: 2px; }
    .convos-message .secondary-content, .convos-message .secondary-content a {
      color: #3c3c3c;
      font-size: 0.8rem;
      overflow: hidden;
      display: block; }
    .convos-message .secondary-content i {
      vertical-align: bottom; }

@media only screen and (min-width: 601px) {
  .convos-help h5 {
    clear: left; }
  .convos-help dl {
    overflow: hidden; }
  .convos-help dl dt {
    width: 15.5em;
    clear: left;
    float: left; }
  .convos-help dl dd {
    margin-left: 16em; } }

body.no-header .convos-dialog-container main,
body.no-header .convos-settings main {
  top: 0; }

body.no-menu .convos-dialog-container,
body.no-menu .convos-settings {
  margin-left: 0; }

header {
  background-color: #3c813f;
  text-align: right;
  height: 56px;
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  z-index: 900; }
  header h2 {
    float: left;
    margin: 0; }
  header h2, header a, header .material-icons, header .le-paste .le-meta::before, .le-paste header .le-meta::before {
    color: #fff;
    display: inline-block;
    font-size: 2rem;
    height: 56px;
    line-height: 56px; }
  header a, header svg, header .material-icons, header .le-paste .le-meta::before, .le-paste header .le-meta::before {
    vertical-align: middle; }
  header a {
    padding-left: 10px;
    padding-right: 10px; }
  header a.active {
    background: #346f37; }
  header a.btn-floating {
    vertical-align: text-bottom; }
  header a.btn-floating i {
    font-size: 1em;
    height: 1em;
    width: 37px;
    line-height: 37px; }
  header .input-field {
    height: 100%;
    padding: 0 1.5rem;
    margin: 0;
    margin-right: 0.75rem;
    width: 240px;
    float: left; }
    @media only screen and (max-width: 992px) {
      header .input-field {
        display: none; } }
    header .input-field input[type="search"] {
      font-size: 1.2rem;
      height: 100%;
      width: 100%;
      border: none;
      margin: 0;
      padding-left: 1rem; }
      header .input-field input[type="search"], header .input-field input[type="search"]:focus {
        color: #fff; }
      header .input-field input[type="search"]:focus, header .input-field input[type="search"][type=text]:valid {
        background: transparent;
        border: none;
        box-shadow: none; }
    header .input-field input[type="search"] + label {
      top: 0;
      left: 0.75rem; }
      header .input-field input[type="search"] + label i {
        font-size: 24px;
        color: rgba(255, 255, 255, 0.7);
        transition: color .3s; }
      header .input-field input[type="search"] + label.active {
        transform: translateY(0); }
    header .input-field input[type="search"]:focus + label i {
      color: #fff; }
  @media only screen and (min-width: 993px) {
    header {
      height: 64px; }
      header h2, header a, header .material-icons, header .le-paste .le-meta::before, .le-paste header .le-meta::before {
        height: 64px;
        line-height: 64px; } }
  @media only screen and (max-width: 992px) {
    header a.toggle-main-menu {
      margin-right: 0.75rem; } }
  header ::-webkit-input-placeholder {
    color: #6ab96d; }
  header :-moz-placeholder {
    color: #6ab96d; }
  header ::-moz-placeholder {
    color: #6ab96d; }
  header :-ms-input-placeholder {
    color: #6ab96d; }
  header .convos-icon {
    fill: #fff; }

a.toggle-main-menu {
  float: left; }

.convos-dialog-container header h2,
.convos-settings header h2 {
  padding-left: 0.75rem; }

.under-main-menu {
  padding-top: 56px; }
  @media only screen and (min-width: 993px) {
    .under-main-menu {
      padding-top: 64px; } }
  .under-main-menu.max-height {
    height: 100vh;
    overflow: hidden; }

body.notouch header a:hover {
  background: #449248; }

body.no-header header {
  display: none; }

body.no-menu header {
  padding-left: 1.5rem; }
  body.no-menu header .input-field {
    display: none; }

body.no-sidebar .convos-header-links {
  display: none !important; }

.le-rich,
.le-photo {
  overflow: hidden;
  display: block;
  max-width: 100%;
  max-height: 20rem;
  margin: 6px 0; }
  @media only screen and (min-width: 601px) {
    .le-rich,
    .le-photo {
      max-height: none; } }

blockquote.le-card,
div.le-card {
  background: #f2f2f2;
  border: 1px solid #e1e1e1;
  padding: 0.5rem;
  margin: 0.3rem 0; }

.le-card .le-thumbnail-placeholder,
.le-rich .le-thumbnail-placeholder {
  display: none; }

.le-card .le-thumbnail,
.le-rich .le-thumbnail {
  float: left; }
  .le-card .le-thumbnail img,
  .le-rich .le-thumbnail img {
    max-height: 50px;
    margin-right: 8px;
    border: 0;
    box-shadow: none;
    vertical-align: bottom; }

.le-card h3,
.le-rich h3 {
  font-size: 1em;
  line-height: 1em;
  display: block;
  margin: 0; }

.le-card p,
.le-rich p {
  font-size: 0.9em;
  line-height: 1.2em;
  margin: 4px 0;
  display: table-cell; }

.le-provider-link ~ .le-goto-link:before,
.le-author-link ~ .le-goto-link:before {
  content: "\2013\00a0"; }

.le-paste .le-provider-link:before {
  content: "Hosted by "; }

.le-video video {
  background: #f2f2f2;
  border: 1px solid #e1e1e1;
  display: block;
  width: 100%;
  height: auto; }

.le-image-card .le-goto-link {
  display: none; }

.le-photo img {
  max-height: 220px; }

.materialboxed {
  cursor: zoom-in;
  border-radius: 2px;
  transition: box-shadow .3s;
  box-shadow: none; }
  .materialboxed:hover {
    box-shadow: 0 3px 7px 0 rgba(0, 0, 0, 0.2); }

.materialbox-overlay {
  background-color: #292929;
  width: 0;
  overflow: hidden;
  position: fixed;
  bottom: 0;
  left: 0;
  top: 0;
  z-index: 1001;
  opacity: 0.01;
  cursor: zoom-out; }
  .materialbox-overlay img {
    transition: width .3s ease-in-out, height .3s ease-in-out, left .3s ease-in-out, top .3s ease-in-out; }
  .materialbox-overlay.active {
    display: block;
    opacity: 0.98;
    width: 100%; }

.hljs {
  font-family: "SFMono-Regular", Consolas, "Liberation Mono", Menlo, monospace;
  font-size: 0.9rem;
  line-height: 1.3rem;
  white-space: pre; }

.le-paste {
  background: #f8f8f8;
  border: 1px solid #dfdfdf;
  max-height: 80px;
  max-width: 100%;
  overflow: hidden; }
  .le-paste .le-meta {
    background-color: #dfdfdf;
    color: #222;
    padding: 0.2em 0.5rem;
    margin: 0;
    cursor: zoom-in; }
    .le-paste .le-meta::before {
      font-size: 1.6rem !important;
      content: '\e313';
      float: right; }
  .le-paste ol {
    margin: 0.2rem 0; }
  .le-paste.expanded {
    max-height: none;
    overflow-x: auto; }
    .le-paste.expanded .le-meta {
      cursor: zoom-out; }
      .le-paste.expanded .le-meta::before {
        content: '\e316'; }

div.paste {
  margin-bottom: 3rem;
  border-bottom: 1px solid #dfdfdf; }
  div.paste h1 {
    font-size: 2rem; }

.convos-main-menu,
.is-sidebar {
  width: 100%;
  background-color: whitesmoke;
  position: absolute;
  top: 56px;
  bottom: 0;
  z-index: 901;
  -webkit-overflow-scrolling: touch;
  overflow: auto; }
  @media only screen and (min-width: 993px) {
    .convos-main-menu,
    .is-sidebar {
      top: 64px; } }
  .convos-main-menu.hidden,
  .is-sidebar.hidden {
    display: none !important; }

.convos-main-menu {
  left: 0; }
  @media only screen and (min-width: 993px) {
    .convos-main-menu {
      width: 240px; }
      .convos-main-menu.show-on-large {
        display: block !important; } }
  .convos-main-menu .link {
    display: block;
    position: relative; }
    .convos-main-menu .link a {
      padding: 0.75rem;
      display: block; }
    .convos-main-menu .link:hover, .convos-main-menu .link.focus {
      background-color: #e6e6e6; }
    .convos-main-menu .link.active {
      background-color: #fafafa; }
      .convos-main-menu .link.active a {
        color: #244d26;
        font-weight: bold; }
    .convos-main-menu .link.frozen a {
      color: #B71C1C; }
    .convos-main-menu .link .material-icons, .convos-main-menu .link .le-paste .le-meta::before, .le-paste .convos-main-menu .link .le-meta::before {
      vertical-align: top; }
    .convos-main-menu .link.simple .material-icons, .convos-main-menu .link.simple .le-paste .le-meta::before, .le-paste .convos-main-menu .link.simple .le-meta::before {
      vertical-align: bottom; }
  .convos-main-menu .on {
    display: block;
    font-size: 0.9rem;
    color: #6f6f6f;
    margin-left: 28px;
    margin-bottom: -5px; }
  .convos-main-menu .close, .convos-main-menu .n-unread {
    color: #fff;
    font-weight: 300;
    min-width: auto;
    border-radius: 2px;
    top: 0.85rem;
    right: 0.75rem; }
  .convos-main-menu .n-unread {
    background-color: #2c5e2e;
    font-size: 0.9rem; }
  .convos-main-menu .close {
    background-color: #B71C1C;
    font-size: 1.2rem;
    line-height: 1.35rem;
    padding: 0 4px;
    cursor: pointer;
    display: none; }

.is-sidebar {
  right: 0; }
  @media only screen and (min-width: 993px) {
    .is-sidebar {
      width: 320px; } }

.convos-sidebar-info .row,
.convos-notifications .row {
  margin-bottom: 0.75rem; }

.convos-sidebar-info .menu-item,
.convos-notifications .menu-item {
  border-top: 1px solid #e8e8e8;
  border-bottom: 1px solid #e8e8e8;
  margin-top: -1px;
  padding: 0 0.75rem;
  overflow: hidden; }
  .convos-sidebar-info .menu-item, .convos-sidebar-info .menu-item i,
  .convos-notifications .menu-item,
  .convos-notifications .menu-item i {
    line-height: 2.1rem; }
  .convos-sidebar-info .menu-item:hover,
  .convos-notifications .menu-item:hover {
    background-color: #e6e6e6; }
  .convos-sidebar-info .menu-item .material-icons, .convos-sidebar-info .menu-item .le-paste .le-meta::before, .le-paste .convos-sidebar-info .menu-item .le-meta::before,
  .convos-notifications .menu-item .material-icons,
  .convos-notifications .menu-item .le-paste .le-meta::before, .le-paste
  .convos-notifications .menu-item .le-meta::before {
    vertical-align: text-bottom; }
  .convos-sidebar-info .menu-item > a:only-child,
  .convos-notifications .menu-item > a:only-child {
    display: block; }

.convos-sidebar-info .btn-floating,
.convos-notifications .btn-floating {
  box-shadow: none;
  vertical-align: middle;
  float: right;
  top: -6px; }

.convos-sidebar-info .notification,
.convos-notifications .notification {
  display: block;
  cursor: pointer;
  padding-top: 4px;
  padding-bottom: 8px;
  border-bottom: 1px solid #e6e6e6; }
  .convos-sidebar-info .notification h5, .convos-sidebar-info .notification .secondary-content,
  .convos-notifications .notification h5,
  .convos-notifications .notification .secondary-content {
    font-size: 1rem;
    line-height: 110%;
    margin: 0.5rem 0 0.4rem 0; }
  .convos-sidebar-info .notification.read,
  .convos-notifications .notification.read {
    opacity: 0.7; }

.on-connect-commands textarea.materialize-textarea {
  padding: 0.6rem 0;
  height: 1.6rem;
  min-height: 1.6rem;
  max-height: 9.5rem;
  overflow: auto; }

header a.notifications {
  position: relative; }
  header a.notifications i.active {
    position: relative; }
  header a.notifications b.n-notifications {
    color: #e6e6e6;
    font-size: 1rem;
    line-height: 1rem;
    position: absolute;
    bottom: 5px;
    right: 5px; }

body.notouch .convos-main-menu .link.dialog:hover .close {
  display: block; }

body.notouch .convos-main-menu .link.dialog:hover .close:hover {
  background-color: #8b1515; }

body.notouch .convos-main-menu .link.dialog:hover .n-unread {
  display: none; }

body.no-header .convos-main-menu,
body.no-header .is-sidebar {
  top: 0; }

body.no-menu .convos-main-menu {
  display: none !important; }

body.no-sidebar .is-sidebar {
  display: none !important; }

/*# sourceMappingURL=../9b345dff2a/main.css.map */